@@ -32,10 +32,9 @@
 #ifdef APDK_APOLLO21XX
 
 #include "header.h"
-//#include "io_defs.h"
-
 #include "apollo2xxx.h"
 #include "apollo21xx.h"
+#include "printerproxy.h"
 
 APDK_BEGIN_NAMESPACE
 
@@ -45,6 +44,23 @@ extern uint32_t ulMapVOLTAIRE_CCM_KCMY[ 9 * 9 * 9 ];
 extern uint32_t ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
 extern uint32_t ulMapVOLTAIRE_CCM_CMY[ 9 * 9 * 9 ];
 
+//! Apollo21xxProxy
+/*!
+******************************************************************************/
+static class Apollo21xxProxy : public PrinterProxy
+{
+public:
+    Apollo21xxProxy() : PrinterProxy(
+        "AP21xx",                   // family name
+        "P-2000U\0"                             // Apollo P2000U
+    ) {}
+    inline Printer* CreatePrinter(SystemServices* pSS) const { return new Apollo21xx(pSS); }
+} Apollo21xxProxy;
+
+
+//! Constructor for Apollo21xx
+/*!
+******************************************************************************/
 Apollo21xx::Apollo21xx(SystemServices* pSS, BOOL proto)
     : Apollo2xxx(pSS,proto)
 {
