@@ -32,10 +32,9 @@
 #ifdef APDK_APOLLO2560
 
 #include "header.h"
-//#include "io_defs.h"
-
 #include "apollo2xxx.h"
 #include "apollo2560.h"
+#include "printerproxy.h"
 
 APDK_BEGIN_NAMESPACE
 
@@ -45,6 +44,21 @@ extern uint32_t ulMapVOLTAIRE_CCM_KCMY[ 9 * 9 * 9 ];
 extern uint32_t ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
 extern uint32_t ulMapVOLTAIRE_CCM_CMY[ 9 * 9 * 9 ];
 
+//! Apollo2560Proxy
+/*!
+******************************************************************************/
+static class Apollo2560Proxy : public PrinterProxy
+{
+public:
+    Apollo2560Proxy() : PrinterProxy(
+        "AP2560",                   // family name
+        "APOLLO P2500/2600\0"                   // Apollo P2500 & P2600
+    ) {}
+    inline Printer* CreatePrinter(SystemServices* pSS) const { return new Apollo2560(pSS); }
+} Apollo2560Proxy;
+
+
+
 Apollo2560::Apollo2560(SystemServices* pSS, BOOL proto)
     : Apollo2xxx(pSS,proto)
 // for 2500/2600
