@@ -28,14 +28,8 @@
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 \*****************************************************************************/
 
-
-#ifdef APDK_PROTO
-#include "..\common\config.h"
-#include "..\common\resources.h"
-#else
 #include "config.h"
 #include "resources.h"
-#endif
 
 APDK_BEGIN_NAMESPACE
 
@@ -819,6 +813,267 @@ const unsigned char HT600x6004level895_open[1024]=
    2 ,  239 ,    0 ,    0
 };
 
+const unsigned char HT300x3004level970_open[1024]=
+
+{
+   0 ,    0 ,  255 ,    0 ,
+   0 ,    0 ,  255 ,    0 ,
+   0 ,    6 ,  255 ,    6 ,
+   0 ,    9 ,  255 ,    9 ,
+   0 ,   12 ,  255 ,   12 ,
+   0 ,   15 ,  255 ,   15 ,
+   0 ,   18 ,  255 ,   18 ,
+   0 ,   21 ,  255 ,   21 ,
+   0 ,   24 ,  255 ,   24 ,
+   0 ,   27 ,  255 ,   27 ,
+   0 ,   30 ,  255 ,   30 ,
+   0 ,   33 ,  255 ,   33 ,
+   0 ,   36 ,  255 ,   36 ,
+   0 ,   39 ,  255 ,   39 ,
+   0 ,   42 ,  255 ,   42 ,
+   0 ,   45 ,  255 ,   45 ,
+   0 ,   48 ,  255 ,   48 ,
+   0 ,   51 ,  255 ,   51 ,
+   0 ,   54 ,  255 ,   54 ,
+   0 ,   57 ,  255 ,   57 ,
+   0 ,   60 ,  255 ,   60 ,
+   0 ,   63 ,  255 ,   63 ,
+   0 ,   66 ,  255 ,   66 ,
+   0 ,   69 ,  255 ,   69 ,
+   0 ,   72 ,  255 ,   72 ,
+   0 ,   75 ,  255 ,   75 ,
+   0 ,   78 ,  255 ,   78 ,
+   0 ,   81 ,  255 ,   81 ,
+   0 ,   84 ,  255 ,   84 ,
+   0 ,   87 ,  255 ,   87 ,
+   0 ,   90 ,  255 ,   90 ,
+   0 ,   93 ,  255 ,   93 ,
+   0 ,   96 ,  255 ,   96 ,
+   0 ,   99 ,  255 ,   99 ,
+   0 ,  102 ,  255 ,  102 ,
+   0 ,  105 ,  255 ,  105 ,
+   0 ,  108 ,  255 ,  108 ,
+   0 ,  111 ,  255 ,  111 ,
+   0 ,  114 ,  255 ,  114 ,
+   0 ,  117 ,  255 ,  117 ,
+   0 ,  120 ,  255 ,  120 ,
+   0 ,  123 ,  255 ,  123 ,
+   0 ,  126 ,  255 ,  126 ,
+   0 ,  129 ,  255 ,  129 ,
+   0 ,  132 ,  255 ,  132 ,
+   0 ,  135 ,  255 ,  135 ,
+   0 ,  138 ,  255 ,  138 ,
+   0 ,  141 ,  255 ,  141 ,
+   0 ,  144 ,  255 ,  144 ,
+   0 ,  147 ,  255 ,  147 ,
+   0 ,  150 ,  255 ,  150 ,
+   0 ,  153 ,  255 ,  153 ,
+   0 ,  156 ,  255 ,  156 ,
+   0 ,  159 ,  255 ,  159 ,
+   0 ,  162 ,  255 ,  162 ,
+   0 ,  165 ,  255 ,  165 ,
+   0 ,  168 ,  255 ,  168 ,
+   0 ,  171 ,  255 ,  171 ,
+   0 ,  174 ,  255 ,  174 ,
+   0 ,  177 ,  255 ,  177 ,
+   0 ,  180 ,  255 ,  180 ,
+   0 ,  183 ,  255 ,  183 ,
+   0 ,  186 ,  255 ,  186 ,
+   0 ,  189 ,  255 ,  189 ,
+   0 ,  192 ,  255 ,  192 ,
+   0 ,  195 ,  255 ,  195 ,
+   0 ,  198 ,  255 ,  198 ,
+   0 ,  201 ,  255 ,  201 ,
+   0 ,  204 ,  255 ,  204 ,
+   0 ,  207 ,  255 ,  207 ,
+   0 ,  210 ,  255 ,  210 ,
+   0 ,  213 ,  255 ,  213 ,
+   0 ,  216 ,  255 ,  216 ,
+   0 ,  219 ,  255 ,  219 ,
+   0 ,  222 ,  255 ,  222 ,
+   0 ,  225 ,  255 ,  225 ,
+   0 ,  228 ,  255 ,  228 ,
+   0 ,  231 ,  255 ,  231 ,
+   0 ,  234 ,  255 ,  234 ,
+   0 ,  237 ,  255 ,  237 ,
+   0 ,  240 ,  255 ,  240 ,
+   0 ,  243 ,  255 ,  243 ,
+   0 ,  246 ,  255 ,  246 ,
+   0 ,  249 ,  255 ,  249 ,
+   0 ,  252 ,  255 ,  252 ,
+   1 ,    0 ,  255 ,    0 ,
+   1 ,    3 ,  255 ,    3 ,
+   1 ,    6 ,  255 ,    6 ,
+   1 ,    9 ,  255 ,    9 ,
+   1 ,   12 ,  255 ,   12 ,
+   1 ,   15 ,  255 ,   15 ,
+   1 ,   18 ,  255 ,   18 ,
+   1 ,   21 ,  255 ,   21 ,
+   1 ,   24 ,  255 ,   24 ,
+   1 ,   27 ,  255 ,   27 ,
+   1 ,   30 ,  255 ,   30 ,
+   1 ,   33 ,  255 ,   33 ,
+   1 ,   36 ,  255 ,   36 ,
+   1 ,   39 ,  255 ,   39 ,
+   1 ,   42 ,  255 ,   42 ,
+   1 ,   45 ,  255 ,   45 ,
+   1 ,   48 ,  255 ,   48 ,
+   1 ,   51 ,  255 ,   51 ,
+   1 ,   54 ,  255 ,   54 ,
+   1 ,   57 ,  255 ,   57 ,
+   1 ,   60 ,  255 ,   60 ,
+   1 ,   63 ,  255 ,   63 ,
+   1 ,   66 ,  255 ,   66 ,
+   1 ,   69 ,  255 ,   69 ,
+   1 ,   72 ,  255 ,   72 ,
+   1 ,   75 ,  255 ,   75 ,
+   1 ,   78 ,  255 ,   78 ,
+   1 ,   81 ,  255 ,   81 ,
+   1 ,   84 ,  255 ,   84 ,
+   1 ,   87 ,  255 ,   87 ,
+   1 ,   90 ,  255 ,   90 ,
+   1 ,   93 ,  255 ,   93 ,
+   1 ,   96 ,  255 ,   96 ,
+   1 ,   99 ,  255 ,   99 ,
+   1 ,  102 ,  255 ,  102 ,
+   1 ,  105 ,  255 ,  105 ,
+   1 ,  108 ,  255 ,  108 ,
+   1 ,  111 ,  255 ,  111 ,
+   1 ,  114 ,  255 ,  114 ,
+   1 ,  117 ,  255 ,  117 ,
+   1 ,  120 ,  255 ,  120 ,
+   1 ,  123 ,  255 ,  123 ,
+   1 ,  126 ,  255 ,  126 ,
+   1 ,  129 ,  255 ,  129 ,
+   1 ,  132 ,  255 ,  132 ,
+   1 ,  135 ,  255 ,  135 ,
+   1 ,  138 ,  255 ,  138 ,
+   1 ,  141 ,  255 ,  141 ,
+   1 ,  144 ,  255 ,  144 ,
+   1 ,  147 ,  255 ,  147 ,
+   1 ,  150 ,  255 ,  150 ,
+   1 ,  153 ,  255 ,  153 ,
+   1 ,  156 ,  255 ,  156 ,
+   1 ,  159 ,  255 ,  159 ,
+   1 ,  162 ,  255 ,  162 ,
+   1 ,  165 ,  255 ,  165 ,
+   1 ,  168 ,  255 ,  168 ,
+   1 ,  171 ,  255 ,  171 ,
+   1 ,  174 ,  255 ,  174 ,
+   1 ,  177 ,  255 ,  177 ,
+   1 ,  180 ,  255 ,  180 ,
+   1 ,  183 ,  255 ,  183 ,
+   1 ,  186 ,  255 ,  186 ,
+   1 ,  189 ,  255 ,  189 ,
+   1 ,  192 ,  255 ,  192 ,
+   1 ,  195 ,  255 ,  195 ,
+   1 ,  198 ,  255 ,  198 ,
+   1 ,  201 ,  255 ,  201 ,
+   1 ,  204 ,  255 ,  204 ,
+   1 ,  207 ,  255 ,  207 ,
+   1 ,  210 ,  255 ,  210 ,
+   1 ,  213 ,  255 ,  213 ,
+   1 ,  216 ,  255 ,  216 ,
+   1 ,  219 ,  255 ,  219 ,
+   1 ,  222 ,  255 ,  222 ,
+   1 ,  225 ,  255 ,  225 ,
+   1 ,  228 ,  255 ,  228 ,
+   1 ,  231 ,  255 ,  231 ,
+   1 ,  234 ,  255 ,  234 ,
+   1 ,  237 ,  255 ,  237 ,
+   1 ,  240 ,  255 ,  240 ,
+   1 ,  243 ,  255 ,  243 ,
+   1 ,  246 ,  255 ,  246 ,
+   1 ,  249 ,  255 ,  249 ,
+   1 ,  252 ,  255 ,  252 ,
+   2 ,    0 ,  255 ,    0 ,
+   2 ,    3 ,  255 ,    3 ,
+   2 ,    6 ,  255 ,    6 ,
+   2 ,    9 ,  255 ,    9 ,
+   2 ,   12 ,  255 ,   12 ,
+   2 ,   15 ,  255 ,   15 ,
+   2 ,   18 ,  255 ,   18 ,
+   2 ,   21 ,  255 ,   21 ,
+   2 ,   24 ,  255 ,   24 ,
+   2 ,   27 ,  255 ,   27 ,
+   2 ,   30 ,  255 ,   30 ,
+   2 ,   33 ,  255 ,   33 ,
+   2 ,   36 ,  255 ,   36 ,
+   2 ,   39 ,  255 ,   39 ,
+   2 ,   42 ,  255 ,   42 ,
+   2 ,   45 ,  255 ,   45 ,
+   2 ,   48 ,  255 ,   48 ,
+   2 ,   51 ,  255 ,   51 ,
+   2 ,   54 ,  255 ,   54 ,
+   2 ,   57 ,  255 ,   57 ,
+   2 ,   60 ,  255 ,   60 ,
+   2 ,   63 ,  255 ,   63 ,
+   2 ,   66 ,  255 ,   66 ,
+   2 ,   69 ,  255 ,   69 ,
+   2 ,   72 ,  255 ,   72 ,
+   2 ,   75 ,  255 ,   75 ,
+   2 ,   78 ,  255 ,   78 ,
+   2 ,   81 ,  255 ,   81 ,
+   2 ,   84 ,  255 ,   84 ,
+   2 ,   87 ,  255 ,   87 ,
+   2 ,   90 ,  255 ,   90 ,
+   2 ,   93 ,  255 ,   93 ,
+   2 ,   96 ,  255 ,   96 ,
+   2 ,   99 ,  255 ,   99 ,
+   2 ,  102 ,  255 ,  102 ,
+   2 ,  105 ,  255 ,  105 ,
+   2 ,  108 ,  255 ,  108 ,
+   2 ,  111 ,  255 ,  111 ,
+   2 ,  114 ,  255 ,  114 ,
+   2 ,  117 ,  255 ,  117 ,
+   2 ,  120 ,  255 ,  120 ,
+   2 ,  123 ,  255 ,  123 ,
+   2 ,  126 ,  255 ,  126 ,
+   2 ,  129 ,  255 ,  129 ,
+   2 ,  132 ,  255 ,  132 ,
+   2 ,  135 ,  255 ,  135 ,
+   2 ,  138 ,  255 ,  138 ,
+   2 ,  141 ,  255 ,  141 ,
+   2 ,  144 ,  255 ,  144 ,
+   2 ,  147 ,  255 ,  147 ,
+   2 ,  150 ,  255 ,  150 ,
+   2 ,  153 ,  255 ,  153 ,
+   2 ,  156 ,  255 ,  156 ,
+   2 ,  159 ,  255 ,  159 ,
+   2 ,  162 ,  255 ,  162 ,
+   2 ,  165 ,  255 ,  165 ,
+   2 ,  168 ,  255 ,  168 ,
+   2 ,  171 ,  255 ,  171 ,
+   2 ,  174 ,  255 ,  174 ,
+   2 ,  177 ,  255 ,  177 ,
+   2 ,  180 ,  255 ,  180 ,
+   2 ,  183 ,  255 ,  183 ,
+   2 ,  186 ,  255 ,  186 ,
+   2 ,  189 ,  255 ,  189 ,
+   2 ,  192 ,  255 ,  192 ,
+   2 ,  195 ,  255 ,  195 ,
+   2 ,  198 ,  255 ,  198 ,
+   2 ,  201 ,  255 ,  201 ,
+   2 ,  204 ,  255 ,  204 ,
+   2 ,  207 ,  255 ,  207 ,
+   2 ,  210 ,  255 ,  210 ,
+   2 ,  213 ,  255 ,  213 ,
+   2 ,  216 ,  255 ,  216 ,
+   2 ,  219 ,  255 ,  219 ,
+   2 ,  222 ,  255 ,  222 ,
+   2 ,  225 ,  255 ,  225 ,
+   2 ,  228 ,  255 ,  228 ,
+   2 ,  231 ,  255 ,  231 ,
+   2 ,  234 ,  255 ,  234 ,
+   2 ,  237 ,  255 ,  237 ,
+   2 ,  240 ,  255 ,  240 ,
+   2 ,  243 ,  255 ,  243 ,
+   2 ,  246 ,  255 ,  246 ,
+   2 ,  249 ,  255 ,  249 ,
+   2 ,  252 ,  255 ,  252 ,
+   2 ,  252 ,  255 ,  252
+};
+
 const unsigned char HT600x6004level970_open[1024]=
 
 {
@@ -1080,7 +1335,7 @@ const unsigned char HT600x6004level970_open[1024]=
 2,  255,    255,    0
 };
 
-#ifdef APDK_AUTODUPLEX
+#ifdef APDK_EXTENDED_MEDIASIZE
 
  // 2001.07.09 mrb: Added for photo glossy mode of DJ970
  const unsigned char HT1200x1200x1_PhotoPres970_open[1024]=
@@ -1346,263 +1601,263 @@ const unsigned char HT600x6004level970_open[1024]=
  // 2001.07.09 mrb: Added for presentation mode of DJ970
  const unsigned char HT600x600x4_Pres970_open[1024]=
  {
-    0 ,   0 , 255 ,   0 ,
-    0 ,   0 , 255 ,   0 ,
-    0 ,   2 , 255 ,   0 ,
-    0 ,   3 , 255 ,   0 ,
-    0 ,   4 , 255 ,   0 ,
-    0 ,   5 , 255 ,   0 ,
-    0 ,   6 , 255 ,   0 ,
-    0 ,   7 , 255 ,   0 ,
-    0 ,   8 , 255 ,   0 ,
-    0 ,   9 , 255 ,   0 ,
-    0 ,  10 , 255 ,   0 ,
-    0 ,  11 , 255 ,   0 ,
-    0 ,  12 , 255 ,   0 ,
-    0 ,  13 , 255 ,   0 ,
-    0 ,  14 , 255 ,   0 ,
-    0 ,  15 , 255 ,   0 ,
-    0 ,  16 , 255 ,   0 ,
-    0 ,  17 , 255 ,   0 ,
-    0 ,  18 , 255 ,   0 ,
-    0 ,  19 , 255 ,   0 ,
-    0 ,  20 , 255 ,   0 ,
-    0 ,  21 , 255 ,   0 ,
-    0 ,  22 , 255 ,   0 ,
-    0 ,  23 , 255 ,   0 ,
-    0 ,  24 , 255 ,   0 ,
-    0 ,  25 , 255 ,   0 ,
-    0 ,  26 , 255 ,   0 ,
-    0 ,  27 , 255 ,   0 ,
-    0 ,  28 , 255 ,   0 ,
-    0 ,  29 , 255 ,   0 ,
-    0 ,  30 , 255 ,   0 ,
-    0 ,  31 , 255 ,   0 ,
-    0 ,  32 , 255 ,   0 ,
-    0 ,  33 , 255 ,   0 ,
-    0 ,  34 , 255 ,   0 ,
-    0 ,  35 , 255 ,   0 ,
-    0 ,  36 , 255 ,   0 ,
-    0 ,  37 , 255 ,   0 ,
-    0 ,  38 , 255 ,   0 ,
-    0 ,  39 , 255 ,   0 ,
-    0 ,  40 , 255 ,   0 ,
-    0 ,  41 , 255 ,   0 ,
-    0 ,  42 , 255 ,   0 ,
-    0 ,  43 , 255 ,   0 ,
-    0 ,  44 , 255 ,   0 ,
-    0 ,  45 , 255 ,   0 ,
-    0 ,  46 , 255 ,   0 ,
-    0 ,  47 , 255 ,   0 ,
-    0 ,  48 , 255 ,   0 ,
-    0 ,  49 , 255 ,   0 ,
-    0 ,  50 , 255 ,   0 ,
-    0 ,  51 , 255 ,   0 ,
-    0 ,  52 , 255 ,   0 ,
-    0 ,  53 , 255 ,   0 ,
-    0 ,  54 , 255 ,   0 ,
-    0 ,  55 , 255 ,   0 ,
-    0 ,  56 , 255 ,   0 ,
-    0 ,  57 , 255 ,   0 ,
-    0 ,  58 , 255 ,   0 ,
-    0 ,  59 , 255 ,   0 ,
-    0 ,  60 , 255 ,   0 ,
-    0 ,  61 , 255 ,   0 ,
-    0 ,  62 , 255 ,   0 ,
-    0 ,  63 , 255 ,   0 ,
-    0 ,  64 , 255 ,   0 ,
-    0 ,  65 , 255 ,   0 ,
-    0 ,  66 , 255 ,   0 ,
-    0 ,  67 , 255 ,   0 ,
-    0 ,  68 , 255 ,   0 ,
-    0 ,  69 , 255 ,   0 ,
-    0 ,  70 , 255 ,   0 ,
-    0 ,  71 , 255 ,   0 ,
-    0 ,  72 , 255 ,   0 ,
-    0 ,  73 , 255 ,   0 ,
-    0 ,  74 , 255 ,   0 ,
-    0 ,  75 , 255 ,   0 ,
-    0 ,  76 , 255 ,   0 ,
-    0 ,  77 , 255 ,   0 ,
-    0 ,  78 , 255 ,   0 ,
-    0 ,  79 , 255 ,   0 ,
-    0 ,  80 , 255 ,   0 ,
-    0 ,  81 , 255 ,   0 ,
-    0 ,  82 , 255 ,   0 ,
-    0 ,  83 , 255 ,   0 ,
-    0 ,  84 , 255 ,   0 ,
-    0 ,  85 , 255 ,   0 ,
-    0 ,  86 , 255 ,   0 ,
-    0 ,  87 , 255 ,   0 ,
-    0 ,  88 , 255 ,   0 ,
-    0 ,  89 , 255 ,   0 ,
-    0 ,  90 , 255 ,   0 ,
-    0 ,  91 , 255 ,   0 ,
-    0 ,  92 , 255 ,   0 ,
-    0 ,  93 , 255 ,   0 ,
-    0 ,  94 , 255 ,   0 ,
-    0 ,  95 , 255 ,   0 ,
-    0 ,  96 , 255 ,   0 ,
-    0 ,  97 , 255 ,   0 ,
-    0 ,  98 , 255 ,   0 ,
-    0 ,  99 , 255 ,   0 ,
-    0 , 100 , 255 ,   0 ,
-    0 , 101 , 255 ,   0 ,
-    0 , 102 , 255 ,   0 ,
-    0 , 103 , 255 ,   0 ,
-    0 , 104 , 255 ,   0 ,
-    0 , 105 , 255 ,   0 ,
-    0 , 106 , 255 ,   0 ,
-    0 , 107 , 255 ,   0 ,
-    0 , 108 , 255 ,   0 ,
-    0 , 109 , 255 ,   0 ,
-    0 , 110 , 255 ,   0 ,
-    0 , 111 , 255 ,   0 ,
-    0 , 112 , 255 ,   0 ,
-    0 , 113 , 255 ,   0 ,
-    0 , 114 , 255 ,   0 ,
-    0 , 115 , 255 ,   0 ,
-    0 , 116 , 255 ,   0 ,
-    0 , 117 , 255 ,   0 ,
-    0 , 118 , 255 ,   0 ,
-    0 , 119 , 255 ,   0 ,
-    0 , 120 , 255 ,   0 ,
-    0 , 121 , 255 ,   0 ,
-    0 , 122 , 255 ,   0 ,
-    0 , 123 , 255 ,   0 ,
-    0 , 124 , 255 ,   0 ,
-    0 , 125 , 255 ,   0 ,
-    0 , 126 , 255 ,   0 ,
-    0 , 127 , 255 ,   0 ,
-    0 , 129 , 255 ,   0 ,
-    0 , 131 , 255 ,   0 ,
-    0 , 133 , 255 ,   0 ,
-    0 , 135 , 255 ,   0 ,
-    0 , 137 , 255 ,   0 ,
-    0 , 139 , 255 ,   0 ,
-    0 , 141 , 255 ,   0 ,
-    0 , 143 , 255 ,   0 ,
-    0 , 145 , 255 ,   0 ,
-    0 , 147 , 255 ,   0 ,
-    0 , 149 , 255 ,   0 ,
-    0 , 151 , 255 ,   0 ,
-    0 , 153 , 255 ,   0 ,
-    0 , 155 , 255 ,   0 ,
-    0 , 157 , 255 ,   0 ,
-    0 , 159 , 255 ,   0 ,
-    0 , 161 , 255 ,   0 ,
-    0 , 163 , 255 ,   0 ,
-    0 , 165 , 255 ,   0 ,
-    0 , 167 , 255 ,   0 ,
-    0 , 169 , 255 ,   0 ,
-    0 , 171 , 255 ,   0 ,
-    0 , 173 , 255 ,   0 ,
-    0 , 175 , 255 ,   0 ,
-    0 , 177 , 255 ,   0 ,
-    0 , 179 , 255 ,   0 ,
-    0 , 181 , 255 ,   0 ,
-    0 , 183 , 255 ,   0 ,
-    0 , 185 , 255 ,   0 ,
-    0 , 187 , 255 ,   0 ,
-    0 , 189 , 255 ,   0 ,
-    0 , 191 , 255 ,   0 ,
-    0 , 193 , 255 ,   0 ,
-    0 , 195 , 255 ,   0 ,
-    0 , 197 , 255 ,   0 ,
-    0 , 199 , 255 ,   0 ,
-    0 , 201 , 255 ,   0 ,
-    0 , 203 , 255 ,   0 ,
-    0 , 205 , 255 ,   0 ,
-    0 , 207 , 255 ,   0 ,
-    0 , 209 , 255 ,   0 ,
-    0 , 211 , 255 ,   0 ,
-    0 , 213 , 255 ,   0 ,
-    0 , 215 , 255 ,   0 ,
-    0 , 217 , 255 ,   0 ,
-    0 , 219 , 255 ,   0 ,
-    0 , 221 , 255 ,   0 ,
-    0 , 223 , 255 ,   0 ,
-    0 , 225 , 255 ,   0 ,
-    0 , 227 , 255 ,   0 ,
-    0 , 229 , 255 ,   0 ,
-    0 , 231 , 255 ,   0 ,
-    0 , 233 , 255 ,   0 ,
-    0 , 235 , 255 ,   0 ,
-    0 , 237 , 255 ,   0 ,
-    0 , 239 , 255 ,   0 ,
-    0 , 241 , 255 ,   0 ,
-    0 , 243 , 255 ,   0 ,
-    0 , 245 , 255 ,   0 ,
-    0 , 247 , 255 ,   0 ,
-    0 , 249 , 255 ,   0 ,
-    0 , 251 , 255 ,   0 ,
-    0 , 253 , 255 ,   0 ,
-    0 , 255 , 255 ,   0 ,
-    1 ,   1 , 255 ,   0 ,
-    1 ,   3 , 255 ,   0 ,
-    1 ,   5 , 255 ,   0 ,
-    1 ,   7 , 255 ,   0 ,
-    1 ,   9 , 255 ,   0 ,
-    1 ,  11 , 255 ,   0 ,
-    1 ,  13 , 255 ,   0 ,
-    1 ,  15 , 255 ,   0 ,
-    1 ,  17 , 255 ,   0 ,
-    1 ,  19 , 255 ,   0 ,
-    1 ,  21 , 255 ,   0 ,
-    1 ,  23 , 255 ,   0 ,
-    1 ,  25 , 255 ,   0 ,
-    1 ,  27 , 255 ,   0 ,
-    1 ,  29 , 255 ,   0 ,
-    1 ,  31 , 255 ,   0 ,
-    1 ,  33 , 255 ,   0 ,
-    1 ,  35 , 255 ,   0 ,
-    1 ,  37 , 255 ,   0 ,
-    1 ,  39 , 255 ,   0 ,
-    1 ,  41 , 255 ,   0 ,
-    1 ,  43 , 255 ,   0 ,
-    1 ,  45 , 255 ,   0 ,
-    1 ,  47 , 255 ,   0 ,
-    1 ,  49 , 255 ,   0 ,
-    1 ,  51 , 255 ,   0 ,
-    1 ,  53 , 255 ,   0 ,
-    1 ,  55 , 255 ,   0 ,
-    1 ,  57 , 255 ,   0 ,
-    1 ,  59 , 255 ,   0 ,
-    1 ,  61 , 255 ,   0 ,
-    1 ,  63 , 255 ,   0 ,
-    1 ,  65 , 255 ,   0 ,
-    1 ,  67 , 255 ,   0 ,
-    1 ,  69 , 255 ,   0 ,
-    1 ,  71 , 255 ,   0 ,
-    1 ,  73 , 255 ,   0 ,
-    1 ,  75 , 255 ,   0 ,
-    1 ,  77 , 255 ,   0 ,
-    1 ,  79 , 255 ,   0 ,
-    1 ,  81 , 255 ,   0 ,
-    1 ,  83 , 255 ,   0 ,
-    1 ,  85 , 255 ,   0 ,
-    1 ,  87 , 255 ,   0 ,
-    1 ,  89 , 255 ,   0 ,
-    1 ,  91 , 255 ,   0 ,
-    1 ,  93 , 255 ,   0 ,
-    1 ,  95 , 255 ,   0 ,
-    1 ,  97 , 255 ,   0 ,
-    1 ,  99 , 255 ,   0 ,
-    1 , 101 , 255 ,   0 ,
-    1 , 103 , 255 ,   0 ,
-    1 , 105 , 255 ,   0 ,
-    1 , 107 , 255 ,   0 ,
-    1 , 109 , 255 ,   0 ,
-    1 , 111 , 255 ,   0 ,
-    1 , 113 , 255 ,   0 ,
-    1 , 115 , 255 ,   0 ,
-    1 , 117 , 255 ,   0 ,
-    1 , 119 , 255 ,   0 ,
-    1 , 121 , 255 ,   0 ,
-    1 , 123 , 255 ,   0 ,
-    1 , 125 , 255 ,   0 ,
-    1 , 127 , 255 ,   0
+	0,    0,  255,    0,
+	0,    1,  255,    2,
+	0,    3,  255,    3,
+	0,    4,  255,    5,
+	0,    6,  255,    6,
+	0,    7,  255,    8,
+	0,    9,  255,   10,
+	0,   11,  255,   11,
+	0,   12,  255,   13,
+	0,   14,  255,   14,
+	0,   15,  255,   16,
+	0,   17,  255,   18,
+	0,   19,  255,   19,
+	0,   20,  255,   21,
+	0,   22,  255,   22,
+	0,   23,  255,   24,
+	0,   25,  255,   26,
+	0,   27,  255,   27,
+	0,   28,  255,   29,
+	0,   30,  255,   30,
+	0,   31,  255,   32,
+	0,   33,  255,   34,
+	0,   35,  255,   35,
+	0,   36,  255,   37,
+	0,   38,  255,   38,
+	0,   39,  255,   40,
+	0,   41,  255,   42,
+	0,   43,  255,   43,
+	0,   44,  255,   45,
+	0,   46,  255,   46,
+	0,   47,  255,   48,
+	0,   49,  255,   50,
+	0,   51,  255,   51,
+	0,   52,  255,   53,
+	0,   54,  255,   54,
+	0,   55,  255,   56,
+	0,   57,  255,   57,
+	0,   58,  255,   59,
+	0,   60,  255,   61,
+	0,   62,  255,   62,
+	0,   63,  255,   64,
+	0,   65,  255,   65,
+	0,   66,  255,   67,
+	0,   68,  255,   69,
+	0,   70,  255,   70,
+	0,   71,  255,   72,
+	0,   73,  255,   73,
+	0,   74,  255,   75,
+	0,   76,  255,   77,
+	0,   78,  255,   78,
+	0,   79,  255,   80,
+	0,   81,  255,   81,
+	0,   82,  255,   83,
+	0,   84,  255,   85,
+	0,   86,  255,   86,
+	0,   87,  255,   88,
+	0,   89,  255,   89,
+	0,   90,  255,   91,
+	0,   92,  255,   93,
+	0,   94,  255,   94,
+	0,   95,  255,   96,
+	0,   97,  255,   97,
+	0,   98,  255,   99,
+	0,  100,  255,  101,
+	0,  102,  255,  102,
+	0,  103,  255,  104,
+	0,  105,  255,  105,
+	0,  106,  255,  107,
+	0,  108,  255,  108,
+	0,  109,  255,  110,
+	0,  111,  255,  112,
+	0,  113,  255,  113,
+	0,  114,  255,  115,
+	0,  116,  255,  116,
+	0,  117,  255,  118,
+	0,  119,  255,  120,
+	0,  121,  255,  121,
+	0,  122,  255,  123,
+	0,  124,  255,  124,
+	0,  125,  255,  126,
+	0,  127,  255,  128,
+	0,  129,  255,  129,
+	0,  130,  255,  131,
+	0,  132,  255,  132,
+	0,  133,  255,  134,
+	0,  135,  255,  136,
+	0,  137,  255,  137,
+	0,  138,  255,  139,
+	0,  140,  255,  140,
+	0,  141,  255,  142,
+	0,  143,  255,  144,
+	0,  145,  255,  145,
+	0,  146,  255,  147,
+	0,  148,  255,  148,
+	0,  149,  255,  150,
+	0,  151,  255,  152,
+	0,  153,  255,  153,
+	0,  154,  255,  155,
+	0,  156,  255,  156,
+	0,  157,  255,  158,
+	0,  159,  255,  159,
+	0,  160,  255,  161,
+	0,  162,  255,  163,
+	0,  164,  255,  164,
+	0,  165,  255,  166,
+	0,  167,  255,  167,
+	0,  168,  255,  169,
+	0,  170,  255,  171,
+	0,  172,  255,  172,
+	0,  173,  255,  174,
+	0,  175,  255,  175,
+	0,  176,  255,  177,
+	0,  178,  255,  179,
+	0,  180,  255,  180,
+	0,  181,  255,  182,
+	0,  183,  255,  183,
+	0,  184,  255,  185,
+	0,  186,  255,  187,
+	0,  188,  255,  188,
+	0,  189,  255,  190,
+	0,  191,  255,  191,
+	0,  192,  255,  193,
+	0,  194,  255,  195,
+	0,  196,  255,  196,
+	0,  197,  255,  198,
+	0,  199,  255,  199,
+	0,  200,  255,  201,
+	0,  202,  255,  203,
+	0,  204,  255,  204,
+	0,  205,  255,  206,
+	0,  207,  255,  207,
+	0,  208,  255,  209,
+	0,  210,  255,  210,
+	0,  211,  255,  212,
+	0,  213,  255,  214,
+	0,  215,  255,  215,
+	0,  216,  255,  217,
+	0,  218,  255,  218,
+	0,  219,  255,  220,
+	0,  221,  255,  222,
+	0,  223,  255,  223,
+	0,  224,  255,  225,
+	0,  226,  255,  226,
+	0,  227,  255,  228,
+	0,  229,  255,  230,
+	0,  231,  255,  231,
+	0,  232,  255,  233,
+	0,  234,  255,  234,
+	0,  235,  255,  236,
+	0,  237,  255,  238,
+	0,  239,  255,  239,
+	0,  240,  255,  241,
+	0,  242,  255,  242,
+	0,  243,  255,  244,
+	0,  245,  255,  246,
+	0,  247,  255,  247,
+	0,  248,  255,  249,
+	0,  250,  255,  250,
+	0,  251,  255,  252,
+	0,  253,  255,  254,
+	0,  255,  255,  255,
+	1,    3,  255,    6,
+	1,    7,  255,   10,
+	1,   11,  255,   14,
+	1,   15,  255,   18,
+	1,   19,  255,   22,
+	1,   23,  255,   26,
+	1,   27,  255,   30,
+	1,   31,  255,   34,
+	1,   35,  255,   38,
+	1,   39,  255,   42,
+	1,   43,  255,   46,
+	1,   47,  255,   50,
+	1,   51,  255,   54,
+	1,   55,  255,   58,
+	1,   59,  255,   62,
+	1,   63,  255,   66,
+	1,   67,  255,   70,
+	1,   71,  255,   74,
+	1,   75,  255,   78,
+	1,   79,  255,   82,
+	1,   83,  255,   86,
+	1,   87,  255,   90,
+	1,   91,  255,   94,
+	1,   95,  255,   98,
+	1,   99,  255,  102,
+	1,  103,  255,  106,
+	1,  107,  255,  110,
+	1,  111,  255,  114,
+	1,  115,  255,  118,
+	1,  119,  255,  122,
+	1,  123,  255,  126,
+	1,  127,  255,  130,
+	1,  131,  255,  134,
+	1,  135,  255,  138,
+	1,  139,  255,  142,
+	1,  143,  255,  146,
+	1,  147,  255,  150,
+	1,  151,  255,  154,
+	1,  155,  255,  158,
+	1,  159,  255,  162,
+	1,  163,  255,  166,
+	1,  167,  255,  170,
+	1,  171,  255,  174,
+	1,  175,  255,  178,
+	1,  179,  255,  182,
+	1,  183,  255,  186,
+	1,  187,  255,  190,
+	1,  191,  255,  194,
+	1,  195,  255,  198,
+	1,  199,  255,  202,
+	1,  203,  255,  206,
+	1,  207,  255,  210,
+	1,  211,  255,  214,
+	1,  215,  255,  218,
+	1,  219,  255,  222,
+	1,  223,  255,  226,
+	1,  227,  255,  230,
+	1,  231,  255,  234,
+	1,  235,  255,  238,
+	1,  239,  255,  242,
+	1,  243,  255,  246,
+	1,  247,  255,  250,
+	1,  251,  255,  254,
+	1,  255,  255,  255,
+	2,    8,  255,   15,
+	2,   16,  255,   23,
+	2,   24,  255,   31,
+	2,   32,  255,   40,
+	2,   41,  255,   48,
+	2,   49,  255,   56,
+	2,   57,  255,   64,
+	2,   65,  255,   73,
+	2,   74,  255,   81,
+	2,   82,  255,   89,
+	2,   90,  255,   97,
+	2,   98,  255,  105,
+	2,  106,  255,  114,
+	2,  115,  255,  122,
+	2,  123,  255,  130,
+	2,  131,  255,  138,
+	2,  139,  255,  147,
+	2,  148,  255,  155,
+	2,  156,  255,  163,
+	2,  164,  255,  171,
+	2,  172,  255,  179,
+	2,  180,  255,  188,
+	2,  189,  255,  196,
+	2,  197,  255,  204,
+	2,  205,  255,  212,
+	2,  213,  255,  221,
+	2,  222,  255,  229,
+	2,  230,  255,  237,
+	2,  238,  255,  245,
+	2,  246,  255,  254,
+	2,  255,  255,  255
 };
-#endif // APDK_AUTODUPLEX
+#endif // APDK_EXTENDED_MEDIASIZE
 
 APDK_END_NAMESPACE
