@@ -28,13 +28,7 @@
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 \*****************************************************************************/
 
-
-#ifdef APDK_PROTO
-#include "../common/header.h"
-#else
 #include "header.h"
-#endif
-
 #include "hptypes.h"
 #include "colormatch.h"
 
