@@ -33,12 +33,11 @@
 
 #include "header.h"
 #include "pmselect.h"
+#include "printerfactory.h"
 
 #include "halftoner.h"
 #include "colormatch.h"
 
-
-#ifndef APDK_PROTO
 APDK_BEGIN_NAMESPACE
 extern ColorMatcher* Create_ColorMatcher
 (
@@ -48,14 +47,6 @@ extern ColorMatcher* Create_ColorMatcher
     unsigned int iInputWidth
 );
 APDK_END_NAMESPACE
-#else
-#include "../proprietary/colormatcher_prop.h"
-#include "colormatcher_open.h"
-    extern BOOL ProprietaryImaging();
-    extern BOOL ProprietaryScaling();
-    extern int argColor;
-    extern int argProprietary;
-#endif
 
 APDK_BEGIN_NAMESPACE
 
@@ -129,7 +120,7 @@ const PrintContext::PaperSizeMetrics PrintContext::PSM[MAX_PAPER_SIZE] =
     {
         (float)4.13, (float)5.83,   (float)3.88,  (float)5.705,   (float)0.125
     }
-#ifdef APDK_AUTODUPLEX
+#ifdef APDK_EXTENDED_MEDIASIZE
     ,
     // A3 = 294mm x 419.8mm = 11.69 x 16.53 in.
     {
@@ -210,8 +201,10 @@ PrintContext::PrintContext
     thePaperSize(ps),
     MadeCompGrayMode(FALSE)
 #ifdef APDK_AUTODUPLEX
-    , DuplexMode(DUPLEXMODE_NONE),
-    CustomWidth(0.0),
+    , DuplexMode(DUPLEXMODE_NONE)
+#endif
+#ifdef APDK_EXTENDED_MEDIASIZE
+    , CustomWidth(0.0),
     CustomHeight(0.0)
 #endif
 
@@ -626,7 +619,7 @@ DRIVER_ERROR PrintContext::SelectPrintMode
         return WARN_MODE_MISMATCH;
     }
 
-    return NO_ERROR;
+	return NO_ERROR;
 } //SelectPrintMode
 
 
@@ -789,14 +782,14 @@ float PrintContext::PhysicalPageSizeX()   // returned in inches
     }
 
     float   xOverSpray, yOverSpray;
-
-#ifdef APDK_AUTODUPLEX
+	FullbleedType    fbType;
+#ifdef APDK_EXTENDED_MEDIASIZE
     float PhysicalPageX = (thePaperSize == CUSTOM_SIZE) ? CustomWidth : PSM[thePaperSize].fPhysicalPageX;
 #else
     float PhysicalPageX = PSM[thePaperSize].fPhysicalPageX;
 #endif
 
-    if (bDoFullBleed && (thePrinter->FullBleedCapable (thePaperSize, &xOverSpray, &yOverSpray)))
+    if (bDoFullBleed && (thePrinter->FullBleedCapable (thePaperSize, &fbType, &xOverSpray, &yOverSpray)))
     {
         return (PhysicalPageX + xOverSpray);
     }
@@ -814,14 +807,15 @@ float PrintContext::PhysicalPageSizeY()   // returned in inches
     }
 
     float   xOverSpray, yOverSpray;
+	FullbleedType   fbType;
 
-#ifdef APDK_AUTODUPLEX
+#ifdef APDK_EXTENDED_MEDIASIZE
     float PhysicalPageY = (thePaperSize == CUSTOM_SIZE) ? CustomHeight : PSM[thePaperSize].fPhysicalPageY;
 #else
     float PhysicalPageY = PSM[thePaperSize].fPhysicalPageY;
 #endif
 
-    if (bDoFullBleed && (thePrinter->FullBleedCapable (thePaperSize, &xOverSpray, &yOverSpray)))
+    if (bDoFullBleed && (thePrinter->FullBleedCapable (thePaperSize, &fbType, &xOverSpray, &yOverSpray)))
     {
         return (PhysicalPageY + yOverSpray);
     }
@@ -852,8 +846,9 @@ float PrintContext::printablewidth()
     }
 
     float   xOverSpray, yOverSpray;
+	FullbleedType  fbType;
 
-#ifdef APDK_AUTODUPLEX
+#ifdef APDK_EXTENDED_MEDIASIZE
     float PhysicalPageX = (thePaperSize == CUSTOM_SIZE) ? CustomWidth : PSM[thePaperSize].fPhysicalPageX;
     float PrintablePageX = (thePaperSize == CUSTOM_SIZE) ? CustomWidth - (0.25+0.25) : PSM[thePaperSize].fPrintablePageX;
 #else
@@ -861,7 +856,7 @@ float PrintContext::printablewidth()
     float PrintablePageX = PSM[thePaperSize].fPrintablePageX;
 #endif
 
-    if (bDoFullBleed && (thePrinter->FullBleedCapable (thePaperSize, &xOverSpray, &yOverSpray)))
+    if (bDoFullBleed && (thePrinter->FullBleedCapable (thePaperSize, &fbType, &xOverSpray, &yOverSpray)))
     {
         return (PhysicalPageX + xOverSpray);
     }
@@ -898,11 +893,14 @@ float PrintContext::printableheight()
  *  media sizes that can have tear-off tab. So, for all the media that do not
  *  have a tear-off tab at the bottom, physical height is unaltered, but printable
  *  height is less by bottom margin.
+ *  1/22/03 SY. 
+ *  Starting from MalibuPlus, 4-edge full bleed is possible for most media.  A check
+ *  for 4-edge full bleed capability is needed.
  */
 
     float   xOverSpray, yOverSpray;
-
-#ifdef APDK_AUTODUPLEX
+	FullbleedType   fbType;
+#ifdef APDK_EXTENDED_MEDIASIZE
     float PhysicalPageY = (thePaperSize == CUSTOM_SIZE) ? CustomHeight : PSM[thePaperSize].fPhysicalPageY;
     float PrintablePageY = (thePaperSize == CUSTOM_SIZE) ? CustomHeight - (0.125+0.5) : PSM[thePaperSize].fPrintablePageY;
 #else
@@ -910,12 +908,18 @@ float PrintContext::printableheight()
     float PrintablePageY = PSM[thePaperSize].fPrintablePageY;
 #endif
 
-    if (bDoFullBleed  && (thePrinter->FullBleedCapable (thePaperSize, &xOverSpray, &yOverSpray)))
+    if (bDoFullBleed  && (thePrinter->FullBleedCapable (thePaperSize, &fbType, &xOverSpray, &yOverSpray)))
     {
-        if (thePaperSize == PHOTO_SIZE || thePaperSize == A6_WITH_TEAR_OFF_TAB)
-            return (PhysicalPageY + yOverSpray);
-        else
-            return (PhysicalPageY - (float) 0.5);
+		if (fbType == fullbleed3EdgeAllMedia || 
+			fbType == fullbleed3EdgeNonPhotoMedia || 
+			fbType == fullbleed3EdgePhotoMedia)
+			return (PhysicalPageY - (float) 0.5);
+		else if (fbType == fullbleed4EdgePhotoMedia || 
+			     fbType == fullbleed4EdgeNonPhotoMedia || 
+				 fbType == fullbleed4EdgeAllMedia)
+			return (PhysicalPageY + yOverSpray);
+		else
+			return (PhysicalPageY - (float) 0.5);
     }
 
 /*
@@ -947,14 +951,14 @@ float PrintContext::PrintableStartX() // returned in inches
     }
 
     float   xOverSpray, yOverSpray;
-
-    if (bDoFullBleed && (thePrinter->FullBleedCapable (thePaperSize, &xOverSpray, &yOverSpray)))
+	FullbleedType  fbType;
+    if (bDoFullBleed && (thePrinter->FullBleedCapable (thePaperSize, &fbType, &xOverSpray, &yOverSpray)))
     {
         return (0.0);
     }
 
     // this return value centers the printable page horizontally on the physical page
-#ifdef APDK_AUTODUPLEX
+#ifdef APDK_EXTENDED_MEDIASIZE
     float physwidth = (thePaperSize == CUSTOM_SIZE) ? CustomWidth : PSM[thePaperSize].fPhysicalPageX;
 #else
     float physwidth = PSM[thePaperSize].fPhysicalPageX;
@@ -973,8 +977,9 @@ float PrintContext::PrintableStartY() // returned in inches
     }
 
     float   xOverSpray, yOverSpray;
+	FullbleedType fbType;
 
-    if (bDoFullBleed && (thePrinter->FullBleedCapable (thePaperSize, &xOverSpray, &yOverSpray)))
+    if (bDoFullBleed && (thePrinter->FullBleedCapable (thePaperSize, &fbType, &xOverSpray, &yOverSpray)))
     {
         return (0.0);
     }
@@ -1142,31 +1147,52 @@ remote rendering.
 ******************************************************************************/
 DRIVER_ERROR PrintContext::SelectDevice
 (
-    const BYTE* szDeviceID
+    const char* szDeviceId
 )
 {
-    ASSERT(szDeviceID);
-    return UNSUPPORTED_PRINTER;
+    ASSERT(szDeviceId);
+#ifdef APDK_CAPTURE
+    Capture_SelectDevice(szDeviceId);
+#endif
 
-    //! \todo Need to impliment this method
-/*
-    if (szDeviceID)
-    {
-//        //copy device ID string to system services so every else knows...
-//        strcpy(pSS->strDevID, szDeviceID);
+    DRIVER_ERROR err;
 
-        DRIVER_ERROR err = pSS->DR->ParseDevIDString((const char*)(szDeviceID),
-                    &(pSS->strModel),
-                    &(pSS->VIPVersion),
-                    &(pSS->strPens));
-        ERRCHECK;
-    }
-    else
+    if (thePrinter)     // if printer exists due to bidi or previous call
     {
-        return NULL_POINTER;
+        delete thePrinter;
     }
-    return NO_ERROR
-*/
+
+    FAMILY_HANDLE familyHandle = pPFI->FindDevIdMatch(szDeviceId);
+    if (familyHandle == NULL)
+    {
+        return UNSUPPORTED_PRINTER;
+    }
+    thePrinter = pPFI->CreatePrinter(pSS, familyHandle);
+
+
+    const char* model = pPFI->GetFamilyName(familyHandle);
+
+    pSS->AdjustIO(thePrinter->IOMode, model);
+
+    PAPER_SIZE ps = thePrinter->MandatoryPaperSize();
+    if (ps != UNSUPPORTED_SIZE)
+    {
+        if ((PSM[ps].fPhysicalPageX < PSM[thePaperSize].fPhysicalPageX))
+        {
+            thePaperSize = ps;
+        }
+    }//end if (p != UNSUPPORTED_SIZE)
+
+    if ((err = SelectDefaultMode()) == NO_ERROR)
+    {
+        unsigned int    iRasterWidth = InputIsPageWidth ? 0 : InputWidth;
+        err = setpixelsperrow(iRasterWidth, OutputWidth);
+
+    }//end if((err = SelectDefaultMode()) == NO_ERROR)
+
+    thePrinter->SetPMIndices();
+
+    return err;
 } //SelectDevice
 
 
@@ -1397,21 +1423,12 @@ DRIVER_ERROR PrintContext::SetPaperSize (PAPER_SIZE ps, BOOL bFullBleed)
         return NO_PRINTER_SELECTED;
     }
 
-    /* Version 3.0 and before logic
-    if ((thePrinter->MandatoryPaperSize() != UNSUPPORTED_SIZE) &&
-        (ps != thePaperSize))
-    {
-        return ILLEGAL_PAPERSIZE;
-    }
-    thePaperSize = ps;
-    */
-
     // Version 3.0.1 logic for allowing mandatory paper size or smaller
     PAPER_SIZE  psMandatoryPS;
     DRIVER_ERROR    psError = NO_ERROR;
     if ((psMandatoryPS = thePrinter->MandatoryPaperSize()) != UNSUPPORTED_SIZE)
     {
-#ifdef APDK_AUTODUPLEX
+#ifdef APDK_EXTENDED_MEDIASIZE
         float ReqPhysWidth = (ps == CUSTOM_SIZE) ? CustomWidth : PSM[ps].fPhysicalPageX;
 #else
         float ReqPhysWidth = PSM[ps].fPhysicalPageX;
@@ -1458,20 +1475,42 @@ DRIVER_ERROR PrintContext::SetPaperSize (PAPER_SIZE ps, BOOL bFullBleed)
     if (err == NO_ERROR && bFullBleed)
     {
         float   x;
+		FullbleedType   fbType;
 
 //      Does this printer support full-bleed printing
 
-        if (!(thePrinter->FullBleedCapable (ps, &x, &x)))
+        if (!(thePrinter->FullBleedCapable (ps, &fbType, &x, &x)))
             return WARN_FULL_BLEED_UNSUPPORTED;
 
 //      Media with tear-off tab can do full-bleed on all 4 sides
-
-        if (ps == PHOTO_SIZE || ps == A6_WITH_TEAR_OFF_TAB)
-            return NO_ERROR;
-
-//      No tear-off tab, so full-bleed on 3 sides only and not the bottom
-
-        return WARN_FULL_BLEED_3SIDES;
+		if (fbType == fullbleedNotSupported)
+		{
+			return WARN_FULL_BLEED_UNSUPPORTED;
+		}
+		else if (fbType == fullbleed3EdgeAllMedia)
+		{
+			return WARN_FULL_BLEED_3SIDES;
+		}
+		else if (fbType == fullbleed3EdgeNonPhotoMedia)  // Treat non photo case as all media
+		{
+			return WARN_FULL_BLEED_3SIDES;
+		}
+		else if (fbType == fullbleed3EdgePhotoMedia)
+		{
+			return WARN_FULL_BLEED_3SIDES_PHOTOPAPER_ONLY;
+		}
+		else if (fbType == fullbleed4EdgePhotoMedia)
+		{
+			return WARN_FULL_BLEED_PHOTOPAPER_ONLY;
+		}
+		else if (fbType == fullbleed4EdgeAllMedia)
+		{
+			return NO_ERROR;
+		}
+		else if (fbType == fullbleed4EdgeNonPhotoMedia) // Treat non photo case as all media
+		{
+			return NO_ERROR;
+		}
     }
 
     return err;
@@ -1634,6 +1673,10 @@ BOOL    PrintContext::RotateImageForBackPage ()
     return thePrinter->RotateImageForBackPage ();
 }
 
+#endif
+
+#ifdef APDK_EXTENDED_MEDIASIZE
+
 /*!
 Set custom paper size physical width and height in inches. Used with custom paper size only.
 */
@@ -1644,7 +1687,7 @@ BOOL  PrintContext::SetCustomSize (float width, float height)
     return NO_ERROR;
 }
 
-#endif //APDK_AUTODUPLEX
+#endif //APDK_EXTENDED_MEDIASIZE
 
 
 unsigned int PrintContext::GUITopMargin()
@@ -1763,18 +1806,7 @@ DRIVER_ERROR PrintContext::SetCompGrayMode
         numinks = 4;     // even for MDL_BOTH, 4 is still enough
     }
 
-#ifdef APDK_PROTO
-    if (!ProprietaryImaging())
-    {
-        pColorMatcher = new ColorMatcher_Open(pSS, cm, numinks, OutputWidth);
-    }
-    else
-    {
-        pColorMatcher = new ColorMatcher_Prop(pSS,cm,numinks,OutputWidth);
-    }
-#else
     pColorMatcher = Create_ColorMatcher(pSS, cm,numinks, OutputWidth);
-#endif
 
     err = pColorMatcher->MakeGrayMap(thePrinter->CMYMap, graymap);
     delete pColorMatcher;
@@ -1860,4 +1892,103 @@ DRIVER_ERROR PrintContext::SetMediaSource
     return NO_ERROR;
 }
 
+unsigned int PrintContext::GetCurrentDyeCount()
+{ 
+    return CurrentMode->dyeCount; 
+}
+
+PEN_TYPE PrintContext::GetDefaultPenSet()
+{
+    if (thePrinter==NULL)
+        return NO_PEN;
+    return thePrinter->DefaultPenSet();
+}
+
+PEN_TYPE PrintContext::GetInstalledPens()
+{
+	if(!thePrinter)
+		return NO_PEN;
+	return thePrinter->ePen;
+}
+
+const char* PrintContext::PentypeToString(PEN_TYPE pen)
+{
+	switch(pen)
+	{
+		case BLACK_PEN:
+			return "Black Pen";
+		case COLOR_PEN:
+			return "Color Pen";
+		case BOTH_PENS:
+			return "Both Pens";
+		case MDL_PEN:
+			return "MDL Pen";
+		case MDL_BOTH:
+			return "MDL Both";
+		// no test harness item for these combinations
+		case MDL_AND_BLACK_PENS:
+		case MDL_BLACK_AND_COLOR_PENS:
+		case NO_PEN:
+		case DUMMY_PEN:
+		default:
+			return "No Pen";
+	}
+}
+
+char* PrintContext::PrintModeID()
+{
+	char* res = new char[30];
+	strcpy(res," ");  // so can use strcat from now on
+
+	QUALITY_MODE qm;
+	MEDIATYPE mt;
+	COLORMODE cm;
+	BOOL text;
+
+	GetPrintModeSettings(qm, mt, cm, text);
+
+	switch(qm)
+	{
+	case(QUALITY_NORMAL): strcat(res,"N"); break;
+	case(QUALITY_BEST): strcat(res,"B"); break;
+	case(QUALITY_DRAFT): strcat(res,"D"); break;
+        default: break;
+	}
+	strcat(res," ");
+
+	switch(mt)
+	{
+	case(MEDIA_PLAIN): strcat(res,"P"); break;
+	case(MEDIA_PREMIUM): strcat(res,"C"); break;    // for COATED
+	case(MEDIA_PHOTO): strcat(res,"O"); break;
+        default: break;
+	}
+
+	strcat(res," ");
+
+	switch(cm)
+	{
+	case(COLOR): strcat(res,"C"); break;    
+	case(GREY_K): strcat(res,"G"); break;
+	case(GREY_CMY): strcat(res,"Y"); break;
+        default: break;
+	}
+
+	strcat(res," ");
+
+	if (text)
+	strcat(res,"T");
+	else strcat(res,"N");
+
+	unsigned int index = CurrentMode->myIndex;
+	strcat(res," ");
+	char tmp[3];
+	//	strcat(res,itoa(index,tmp,10));   // itoa is not ANSI C, des
+        sprintf(tmp, "%d", index);
+	strcat(res,tmp);
+
+
+	return res;
+}
+
 APDK_END_NAMESPACE
