@@ -34,7 +34,7 @@
 
 APDK_BEGIN_NAMESPACE
 
-extern char *ModelString[MAX_ID_STRING];
+//extern char *ModelString[MAX_ID_STRING];
 
 /*!
 \internal
@@ -76,23 +76,6 @@ class Mode350CPhoto : public PrintMode
         Mode350CPhoto (uint32_t *map);
 }; //Mode350CPhoto
 
-#endif
-
-#ifdef APDK_PROTO
-extern PEN_TYPE ProtoPenType;
-/*!
-\internal
-*/
-class ProtoDJ350 : public DJ350
-{
-public:
-    ProtoDJ350(ProtoServices* pSS);
-
-  //  DRIVER_ERROR ParsePenInfo(PEN_TYPE& ePen) { ePen=ProtoPenType; return NO_ERROR; }
-
-}; //ProtoDJ350
-
-
 #endif
 
 APDK_END_NAMESPACE
