@@ -82,21 +82,6 @@ public:
 
 }; //Mode400
 
-
-#ifdef APDK_PROTO
-/*!
-\internal
-*/
-class ProtoDJ400 : public DJ400
-{
-public:
-    ProtoDJ400(ProtoServices* pSS);
-
-    DRIVER_ERROR GetC32Status(BYTE *pStatusString, int *pLen);
-}; //ProtoDJ400
-
-#endif //APDK_PROTO
-
 APDK_END_NAMESPACE
 
 #endif //APDK_DJ400_H
