@@ -86,23 +86,6 @@ class PhobosMode5 : public PrintMode
 };
 */
 
-#ifdef APDK_PROTO
-extern PEN_TYPE ProtoPenType;
-/*!
-\internal
-*/
-class ProtoDJ8x5 : public DJ8x5
-{
-public:
-    ProtoDJ8x5 (ProtoServices* pSS);
-
-    DRIVER_ERROR ParsePenInfo(PEN_TYPE& ePen) { ePen=ProtoPenType; return NO_ERROR; }
-
-}; //ProtoDJ8x5
-
-
-#endif //APDK_PROTO
-
 APDK_END_NAMESPACE
 
 #endif //APDK_DJ8X5_H
