@@ -34,7 +34,7 @@
 
 APDK_BEGIN_NAMESPACE
 
-extern char *ModelString[MAX_ID_STRING];
+//extern char *ModelString[MAX_ID_STRING];
 
 /*!
 \internal
@@ -87,7 +87,7 @@ public:
     VeniceMode4();
 }; //VeniceMode4
 
-#ifdef APDK_AUTODUPLEX
+#ifdef APDK_EXTENDED_MEDIASIZE
 
 class VeniceMode5 : public GrayMode
 {
@@ -95,23 +95,7 @@ public:
     VeniceMode5();
 }; //VeniceMode5
 
-#endif //APDK_AUTODUPLEX
-
-#ifdef APDK_PROTO
-extern PEN_TYPE ProtoPenType;
-/*!
-\internal
-*/
-class ProtoDJ8xx : public DJ8xx
-{
-public:
-    ProtoDJ8xx(ProtoServices* pSS);
-
-    DRIVER_ERROR ParsePenInfo(PEN_TYPE& ePen) { ePen=ProtoPenType; return NO_ERROR; }
-}; //ProtoDJ8xx
-
-
-#endif //APDK_PROTO
+#endif //APDK_EXTENDED_MEDIASIZE
 
 APDK_END_NAMESPACE
 
