@@ -36,25 +36,62 @@
 #include "dj8xx.h"
 #include "dj9xx.h"
 #include "resources.h"
+#include "printerproxy.h"
 
-#ifdef APDK_PROTO
-extern int argProprietaryImaging;
-extern BOOL argPhotoTray;
-#else
 APDK_BEGIN_NAMESPACE
 extern BYTE* GetHT3x3_4();
 extern BYTE* GetHT6x6_4_970();
 APDK_END_NAMESPACE
-#endif
 
 APDK_BEGIN_NAMESPACE
 
 extern uint32_t ulMapBROADWAY_KCMY[ 9 * 9 * 9 ];
+extern uint32_t ulMapBROADWAY_KCMY_3x3x2[ 9 * 9 * 9 ];
 extern uint32_t ulMapBROADWAY_Gossimer_Normal_KCMY[ 9 * 9 * 9 ];
 extern uint32_t ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
 extern uint32_t ulMapGRAY_K_6x6x1[9 * 9 * 9];
 extern uint32_t ulMapBROADWAY_Draft_KCMY[9 * 9 * 9];
 
+extern void AsciiHexToBinary(BYTE* dest, char* src, int count);
+
+//! DJ9xxProxy
+/*!
+******************************************************************************/
+static class DJ9xxProxy : public PrinterProxy
+{
+public:
+    DJ9xxProxy() : PrinterProxy(
+        "DJ9xx",                    // family name
+        "DESKJET 91\0"                              // DeskJet 91x Series
+        "DESKJET 92\0"                              // DeskJet 920 - Thriftway Lite
+        "DESKJET 93\0"                              // DeskJet 93x Series
+        "DESKJET 94\0"                              // DeskJet 94x Series
+        "DESKJET 95\0"                              // DeskJet 95x Series
+        "DESKJET 97\0"                              // DeskJet 97x Series
+        "DESKJET 1120\0"                        // DeskJet 1120 - Young Einstein
+        "DESKJET 1125\0"                        // DeskJet 1125 - Young Einstein
+        "DESKJET 3810\0"                            // DeskJet 3810 - Subway
+        "DESKJET 3816\0"                            // DeskJet 3816 - Subway
+        "DESKJET 3820\0"                            // DeskJet 3820 - Subway
+        "DESKJET 3822\0"                            // DeskJet 3822 - Subway
+        "PHOTOSMART P1000\0"                        // PSP 1000
+        "PHOTOSMART P1100\0"                        // PSP 1100
+        "DESKJET 1220\0"                            // DeskJet 1220 - Escher
+		"hp deskjet 9300\0"                         // deskjet 9300 - Escher+
+#ifdef APDK_MLC_PRINTER
+        "OfficeJet K\0"                             // OfficeJet K Series
+        "OfficeJet  K\0"                             // OfficeJet K Series (requested by David Paschal)
+        "OfficeJet V\0"                             // OfficeJet V Series
+        "OfficeJet G\0"                             // OfficeJet G Series
+        "PSC 7\0"                                   // PSC 750
+        "PSC 9\0"                                   // PSC 900 Series
+		"officejet 5100 series\0"                   // officejet 5100 series
+#endif
+    ) {}
+    inline Printer* CreatePrinter(SystemServices* pSS) const { return new DJ9xx(pSS); }
+} DJ9xxProxy;
+
+
 DJ9xx::DJ9xx(SystemServices* pSS, BOOL proto)
 : Printer(pSS,NUM_DJ6XX_FONTS,proto)
 {
@@ -77,6 +114,9 @@ DJ9xx::DJ9xx(SystemServices* pSS, BOOL proto)
  */
 
     bDuplexCapable = TRUE;
+#endif
+
+#ifdef APDK_EXTENDED_MEDIASIZE
     pMode[GRAYMODE_INDEX]      = new BroadwayMode3 ();   // Draft Grayscale K
     pMode[SPECIALMODE_INDEX+1] = new BroadwayMode4 ();   // Normal Grayscale K
     pMode[SPECIALMODE_INDEX+2] = new BroadwayMode5 ();   // Draft Color
@@ -95,7 +135,7 @@ DJ9xx::~DJ9xx()
 { }
 
 BroadwayMode1::BroadwayMode1()   // Normal Color
-: PrintMode(ulMapBROADWAY_KCMY)
+: PrintMode(ulMapBROADWAY_KCMY_3x3x2)
 // 600x600x1 K
 // 300x300x2 CMY
 {
@@ -112,15 +152,7 @@ BroadwayMode1::BroadwayMode1()   // Normal Color
     bDuplexCapable = TRUE;
 #endif
 
-
-#ifdef APDK_PROTO
-    if (!argProprietaryImaging)
-        ColorFEDTable = (BYTE*) HT300x3004level_open;
-    else
-        ColorFEDTable = (BYTE*) HT300x3004level_prop;
-#else
-    ColorFEDTable = GetHT3x3_4();
-#endif
+    ColorFEDTable = (BYTE*) HT300x3004level970_open;
 }
 
 BroadwayMode2::BroadwayMode2()    // Photo
@@ -142,14 +174,7 @@ BroadwayMode2::BroadwayMode2()    // Photo
 
     medium = mediaGlossy;
 
-#ifdef APDK_PROTO
-    if (!argProprietaryImaging)
-        ColorFEDTable = (BYTE*) HT600x6004level970_open;
-    else
-        ColorFEDTable = (BYTE*) HT600x6004level970_prop;
-#else
     ColorFEDTable = GetHT6x6_4_970();
-#endif
 
 //    strcpy(ModeName, "Photo");
     bFontCapable=FALSE;
@@ -161,10 +186,12 @@ BroadwayMode2::BroadwayMode2()    // Photo
     pmMediaType = MEDIA_PHOTO;
 }
 
-#ifdef APDK_AUTODUPLEX
+#ifdef APDK_EXTENDED_MEDIASIZE
 BroadwayMode3::BroadwayMode3 () : GrayMode (ulMapVOLTAIRE_CCM_K)   // Draft Grayscale K
 {
+#ifdef APDK_AUTODUPLEX
     bDuplexCapable = TRUE;
+#endif
     pmQuality = QUALITY_DRAFT;
     theQuality = qualityDraft;
 }
@@ -172,7 +199,9 @@ BroadwayMode3::BroadwayMode3 () : GrayMode (ulMapVOLTAIRE_CCM_K)   // Draft Gray
 BroadwayMode4::BroadwayMode4 () : PrintMode (ulMapGRAY_K_6x6x1)    // Normal Grayscale K
 {
     bFontCapable = FALSE;
+#ifdef APDK_AUTODUPLEX
     bDuplexCapable = TRUE;
+#endif
     ResolutionX[0] =
     ResolutionY[0] = 600;
     BaseResX = 600;
@@ -189,7 +218,9 @@ BroadwayMode5::BroadwayMode5()    // Draft Color
 // 300x300x1 K
 // 300x300x1 CMY
 {
+#ifdef APDK_AUTODUPLEX
     bDuplexCapable = TRUE;
+#endif
     pmQuality = QUALITY_DRAFT;
     theQuality = qualityDraft;
 }
@@ -217,7 +248,9 @@ BroadwayModePres::BroadwayModePres() : PrintMode(ulMapBROADWAY_KCMY)
     // 2001.07.09 mrb: Added for presentation mode of DJ970
     ColorFEDTable = (BYTE*) HT600x600x4_Pres970_open;
 
+#ifdef APDK_AUTODUPLEX
     bDuplexCapable = TRUE;
+#endif
     pmQuality   = QUALITY_BEST;
 }
 
@@ -248,7 +281,7 @@ BroadwayModePhotoPres::BroadwayModePhotoPres()
     pmQuality   = QUALITY_HIGHRES_PHOTO;
     pmMediaType = MEDIA_PHOTO;
 }
-#endif  // APDK_AUTODUPLEX
+#endif  // APDK_EXTENDED_MEDIASIZE
 
 BOOL DJ9xx::UseGUIMode(PrintMode* pPrintMode)
 {
@@ -410,9 +443,6 @@ BOOL DJ9xx::PhotoTrayPresent
     BOOL bQueryPrinter
 )
 {
-#ifdef APDK_PROTO
-    return argPhotoTray;
-#endif
     // present (and not engaged) == 8
     return ((PhotoTrayStatus(bQueryPrinter) & 8) == 8);
 } //PhotoTrayInstalled
@@ -423,9 +453,6 @@ PHOTOTRAY_STATE DJ9xx::PhotoTrayEngaged
     BOOL bQueryPrinter
 )
 {
-#ifdef APDK_PROTO
-    return (PHOTOTRAY_STATE) argPhotoTray;
-#endif
     // present and engaged == 9
     return ((PHOTOTRAY_STATE) ((PhotoTrayStatus(bQueryPrinter) & 9) == 9));
 } //PhotoTrayEngaged
@@ -489,12 +516,12 @@ DISPLAY_STATUS DJ9xx::ParseError(BYTE status_reg)
             return DISPLAY_OUT_OF_PAPER;
         }
 
-		if (DEVICE_PAPER_JAMMED(status_reg))
-		{
-			DBG1("Paper Jammed\n");
-			return DISPLAY_PAPER_JAMMED;
-		}
-		if (DEVICE_IO_TRAP(status_reg))
+        if (DEVICE_PAPER_JAMMED(status_reg))
+        {
+            DBG1("Paper Jammed\n");
+            return DISPLAY_PAPER_JAMMED;
+        }
+        if (DEVICE_IO_TRAP(status_reg))
         {
             DBG1("IO trap\n");
             return DISPLAY_ERROR_TRAP;
@@ -598,25 +625,176 @@ DRIVER_ERROR DJ9xx::VerifyPenInfo()
 
 DRIVER_ERROR DJ9xx::ParsePenInfo(PEN_TYPE& ePen, BOOL QueryPrinter)
 {
-    char	*str;
+    char    *str;
     DRIVER_ERROR err = SetPenInfo (str, QueryPrinter);
     ERRCHECK;
 
-	if (*str != '$')
-	{
-		return BAD_DEVICE_ID;
-	}
+    if (*str != '$')
+    {
+		//Escher+ is having Aladdin style devid string.
+		int num_pens = 0;
+		PEN_TYPE temp_pen1 = NO_PEN;
+		BYTE penInfoBits[4];
+		int iNumMissingPens = 0;
+
+		// the first byte indicates how many pens are supported
+		if ((str[0] >= '0') && (str[0] <= '9'))
+		{
+			num_pens = str[0] - '0';
+		}
+		else if ((str[0] >= 'A') && (str[0] <= 'F'))
+		{
+			num_pens = 10 + (str[0] - 'A');
+		}
+		else
+		{
+			return BAD_DEVICE_ID;
+		}
+
+		if ((int) strlen (str) < (num_pens * 8))
+		{
+			return BAD_DEVICE_ID;
+		}
+
+		//  Aladdin style DevID
+
+		if (pSS->GetVIPVersion () == 1)
+		{
+			if (num_pens < 2)
+			{
+				return UNSUPPORTED_PEN;
+			}
+
+			// parse pen1 (should be black)
+			AsciiHexToBinary(penInfoBits, str+1, 4);
+			penInfoBits[1] &= 0xf8; // mask off ink level trigger bits
+
+			if ((penInfoBits[0] == 0xc1) && (penInfoBits[1] == 0x10))
+			{   // Hobbes
+				temp_pen1 = BLACK_PEN;
+			}
+			else if (penInfoBits[0] == 0xc0)
+			{   // missing pen
+				temp_pen1 = NO_PEN;
+				iNumMissingPens = 1;
+			}
+			else
+			{
+				return UNSUPPORTED_PEN;
+			}
+
+			// now check pen2 (should be color)
+			AsciiHexToBinary(penInfoBits, str+9, 4);
+			penInfoBits[1] &= 0xf8; // mask off ink level trigger bits
+
+			if ((penInfoBits[0] == 0xc2) && (penInfoBits[1] == 0x08))
+			{   // Chinook
+				if (temp_pen1 == BLACK_PEN)
+				{
+					ePen = BOTH_PENS;
+				}
+				else
+				{
+					ePen = COLOR_PEN;
+				}
+			}
+			else if (penInfoBits[0] == 0xc0)
+			{   // missing pen
+				ePen = temp_pen1;
+				iNumMissingPens = 1;
+			}
+			else
+			{
+				return UNSUPPORTED_PEN;
+			}
+
+			return NO_ERROR;
+		}
+
+	//  Check for missing pens
+
+		if (*(str - 1) == '1' && *(str - 2) == '1')
+		{
+			return UNSUPPORTED_PEN;
+		}
+
+		char    *p = str + 1;
+		BYTE    penColor;
+
+		ePen = NO_PEN;
+
+		for (int i = 0; i < num_pens; i++, p += 8)
+		{
+			AsciiHexToBinary (penInfoBits, p, 8);
+
+			if ((penInfoBits[1] & 0xf8) == 0xf8)
+			{
+
+	//          The high 5 bits in the 3rd and 4th nibble (second byte) identify the
+	//          installed pen. If all 5 bits are on, user has installed an incompatible pen.
+
+				return UNSUPPORTED_PEN;
+			}
+
+			if ((penInfoBits[0] & 0x80) != 0x80)        // if Bit 31 is 0, this is not a pen
+			{
+				continue;
+			}
+			penColor = penInfoBits[0] & 0x3F;
+			switch (penColor)
+			{
+				case 0:
+				{
+					iNumMissingPens++;
+					break;
+				}
+				case 1:
+					ePen = BLACK_PEN;
+					break;
+				case 2:
+				{
+					if (ePen == BLACK_PEN)
+					{
+						ePen = BOTH_PENS;
+					}
+					else
+					{
+						ePen = COLOR_PEN;
+					}
+					break;
+				}
+				case 4:             // cyan pen
+				case 5:             // magenta pen
+				case 6:             // yellow pen
+				case 7:             // low dye load cyan pen
+				case 8:             // low dye load magenta pen
+				case 9:             // low dye load yellow pen
+					if (ePen == BLACK_PEN || ePen == BOTH_PENS)
+					{
+						ePen = BOTH_PENS;
+					}
+					else
+					{
+						ePen = COLOR_PEN;
+					}
+					break;
+				default:
+					ePen = UNKNOWN_PEN;
+			}
+		}
+		return NO_ERROR;
+    }
 
     // parse penID
     PEN_TYPE temp_pen1;
     // check pen1, assume it is black, pen2 is color
     switch (str[1])
     {
-        case 'H':		// Hobbes
-		case 'L':		// Linus
-		case 'Z':		// Zorro
-			temp_pen1 = BLACK_PEN;
-			break;
+        case 'H':       // Hobbes
+        case 'L':       // Linus
+        case 'Z':       // Zorro
+            temp_pen1 = BLACK_PEN;
+            break;
         case 'X': return UNSUPPORTED_PEN;
         default:  temp_pen1 = NO_PEN; break;
     }
@@ -625,10 +803,10 @@ DRIVER_ERROR DJ9xx::ParsePenInfo(PEN_TYPE& ePen, BOOL QueryPrinter)
 
     int i = 2;
     while ((i < DevIDBuffSize) && str[i]!='$') i++; // handles variable length penIDs
-	if (i == DevIDBuffSize)
-	{
-		return BAD_DEVICE_ID;
-	}
+    if (i == DevIDBuffSize)
+    {
+        return BAD_DEVICE_ID;
+    }
 
     i++;
 
