@@ -34,10 +34,7 @@
 #include "header.h"
 #include "io_defs.h"
 #include "dj9xxvip.h"
-
-#ifdef APDK_PROTO
-extern BOOL argPhotoTray;
-#endif
+#include "printerproxy.h"
 
 APDK_BEGIN_NAMESPACE
 
@@ -49,6 +46,35 @@ extern uint32_t ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
 
 const char GrayscaleSeq[]= {ESC, '*', 'o', '5', 'W', 0x0B, 0x01, 0x00, 0x00, 0x02};
 extern BYTE EscAmplCopy(BYTE *dest, int num, char end);
+extern void AsciiHexToBinary(BYTE* dest, char* src, int count);
+
+//! DJ9xxVIPProxy
+/*!
+******************************************************************************/
+static class DJ9xxVIPProxy : public PrinterProxy
+{
+public:
+    DJ9xxVIPProxy() : PrinterProxy(
+        "DJ9xxVIP",                     // family name
+        "DESKJET 96\0"                              // DeskJet 96x series
+        "DESKJET 98\0"                              // DeskJet 98x series
+        "DESKJET 99\0"                              // DeskJet 99x series
+        "deskjet 6122\0"                            // deskjet 6122 - Churchill
+        "deskjet 6127\0"                            // deskjet 6127 - FDR
+        "PHOTOSMART 1215\0"                         // PSP 1215
+        "PHOTOSMART 1218\0"                         // PSP 1218
+        "PHOTOSMART 1115\0"                         // PSP 1115
+        "PHOTOSMART 1315\0"                         // PSP 1315
+        "HP BUSINESS INKJET 22\0"                   // 2200, 2230, 2250, 2280 - Nobel
+        "cp1160\0"                                  // CP 1160 - Jupiter Pro
+        "cp1700\0"                                  // CP 1700 - Euler
+#ifdef APDK_MLC_PRINTER
+        "officejet d\0"                             // officejet d series
+        "officejet 7100\0"                          // officejet 7100 series
+#endif
+    ) {}
+    inline Printer* CreatePrinter(SystemServices* pSS) const { return new DJ9xxVIP(pSS); }
+} DJ9xxVIPProxy;
 
 
 DJ9xxVIP::DJ9xxVIP
@@ -85,6 +111,9 @@ DJ9xxVIP::DJ9xxVIP
  */
 
     bDuplexCapable = TRUE;
+#endif 
+
+#ifdef APDK_EXTENDED_MEDIASIZE
     pMode[ModeCount++] = new AladdinKGrayMode ();        // Normal Grayscale K
     pMode[ModeCount++] = new Aladdin2400Mode ();         // HiRes
     pMode[ModeCount++] = new AladdinDraftMode ();        // Draft Color
@@ -113,6 +142,8 @@ GrayModeAladdin::GrayModeAladdin
 
 #ifdef APDK_AUTODUPLEX
     bDuplexCapable = TRUE;
+#endif
+#ifdef APDK_EXTENDED_MEDIASIZE
     theQuality = qualityDraft;
     pmQuality = QUALITY_DRAFT;
 #endif
@@ -173,7 +204,7 @@ AladdinCMYGrayMode::AladdinCMYGrayMode()
     bFontCapable = FALSE;
 } //AladdinCMYGrayMode
 
-#ifdef APDK_AUTODUPLEX
+#ifdef APDK_EXTENDED_MEDIASIZE
 AladdinKGrayMode::AladdinKGrayMode () : PrintMode (NULL)
 {
 
@@ -189,7 +220,9 @@ AladdinKGrayMode::AladdinKGrayMode () : PrintMode (NULL)
 
     Config.bColorImage = FALSE;
 
+#ifdef APDK_AUTODUPLEX
     bDuplexCapable = TRUE;
+#endif
     pmColor = GREY_K;
     bFontCapable = FALSE;
     dyeCount = 1;
@@ -197,40 +230,44 @@ AladdinKGrayMode::AladdinKGrayMode () : PrintMode (NULL)
 
 Aladdin2400Mode::Aladdin2400Mode () : PrintMode (NULL)
 {
-	BaseResX =
-	BaseResY = 1200;
-	ResolutionX[0] = 1200;
-	ResolutionY[0] = 1200;
-	bFontCapable = FALSE;
-	bDuplexCapable = FALSE;
+    BaseResX =
+    BaseResY = 1200;
+    ResolutionX[0] = 1200;
+    ResolutionY[0] = 1200;
+    bFontCapable = FALSE;
+#ifdef APDK_AUTODUPLEX
+    bDuplexCapable = FALSE;
+#endif
 #if defined(APDK_VIP_COLORFILTERING)
     Config.bErnie = TRUE;
 #endif
 
     Config.bColorImage = FALSE;
 
-	medium = mediaHighresPhoto;
-	theQuality = qualityPresentation;
-	pmMediaType = MEDIA_PHOTO;
-	pmQuality = QUALITY_HIGHRES_PHOTO;
+    medium = mediaHighresPhoto;
+    theQuality = qualityPresentation;
+    pmMediaType = MEDIA_PHOTO;
+    pmQuality = QUALITY_HIGHRES_PHOTO;
 } // Aladdin2400Mode
 
 AladdinDraftMode::AladdinDraftMode () : PrintMode (NULL)
 {
-	bFontCapable = FALSE;
-	bDuplexCapable = TRUE;
+    bFontCapable = FALSE;
+#ifdef APDK_AUTODUPLEX
+    bDuplexCapable = TRUE;
+#endif
 #if defined(APDK_VIP_COLORFILTERING)
     Config.bErnie = TRUE;
 #endif
 
    Config.bColorImage = FALSE;
 
-	medium = mediaAuto;
-	theQuality = qualityDraft;
-	pmQuality = QUALITY_DRAFT;
+    medium = mediaAuto;
+    theQuality = qualityDraft;
+    pmQuality = QUALITY_DRAFT;
 } // AladdinDraftMode
 
-#endif  // APDK_AUTODUPLEX
+#endif  // APDK_EXTENDED_MEDIASIZE
 
 /*
  *  Some VIP printers do not have Media Sensing device. To enable
@@ -264,15 +301,19 @@ BOOL DJ9xxVIP::UseGUIMode
     PrintMode* pPrintMode
 )
 {
-
+	if (pPrintMode->medium == mediaHighresPhoto)
+	{
+		return TRUE;
+	}
+	else
+	{
 #ifdef APDK_AUTODUPLEX
-    if ((pPrintMode->QueryDuplexMode() != DUPLEXMODE_NONE) ||
-		pPrintMode->medium == mediaHighresPhoto)
-
-    {
-        return TRUE;
-    }
+		if (pPrintMode->QueryDuplexMode() != DUPLEXMODE_NONE)
+		{
+			return TRUE;
+		}
 #endif
+	}
 #if defined(APDK_FONTS_NEEDED)
 //    return ((!pPrintMode->bFontCapable) && (!PCL3acceptsDriverware));
     return (!pPrintMode->bFontCapable);
@@ -513,10 +554,11 @@ DRIVER_ERROR HeaderAladdin::Send()
     float   fYOverSpray = 0.0;
     float   fLeftOverSpray = 0.0;
     float   fTopOverSpray  = 0.0;
-
+	FullbleedType   fbType;
     if (thePrintContext->bDoFullBleed &&
         thePrinter->FullBleedCapable (thePrintContext->thePaperSize,
-									  &fXOverSpray, &fYOverSpray,
+									  &fbType,
+                                      &fXOverSpray, &fYOverSpray,
                                       &fLeftOverSpray, &fTopOverSpray))
     {
 
@@ -568,7 +610,7 @@ DRIVER_ERROR HeaderAladdin::Send()
         blankRow[30] = 0xCE; blankRow[31] = 0x7F;
         err = thePrinter->Send ((const BYTE *) blankRow, 34);
     }
-    
+
     return err;
 } //Send
 
@@ -604,7 +646,7 @@ DRIVER_ERROR HeaderAladdin::StartSend()
     ERRCHECK;
 
 //  Now send media pre-load command
-    err = thePrinter->Send ((const BYTE *) "\033&l-2H", 6);   
+    err = thePrinter->Send ((const BYTE *) "\033&l-2H", 6);   // Moved from Modes(), des 3/11/03
     ERRCHECK;
 
     if (!thePrinter->UseGUIMode(thePrintContext->CurrentMode))
@@ -634,87 +676,6 @@ void HeaderAladdin::SetMediaSource(MediaSource msource)
     msrccount=EscAmplCopy((BYTE*)mediasource,msource,'H');
 }
 
-void AsciiHexToBinary(BYTE* dest, char* src, int count)
-{
-    int i;
-    BYTE bitPattern;
-    for (i=0; i<count ; i++)
-    {
-        switch (src[i])
-        {
-            case '0':
-                bitPattern = 0x00;
-                break;
-            case '1':
-                bitPattern = 0x01;
-                break;
-            case '2':
-                bitPattern = 0x02;
-                break;
-            case '3':
-                bitPattern = 0x03;
-                break;
-            case '4':
-                bitPattern = 0x04;
-                break;
-            case '5':
-                bitPattern = 0x05;
-                break;
-            case '6':
-                bitPattern = 0x06;
-                break;
-            case '7':
-                bitPattern = 0x07;
-                break;
-            case '8':
-                bitPattern = 0x08;
-                break;
-            case '9':
-                bitPattern = 0x09;
-                break;
-            case 'a':
-            case 'A':
-                bitPattern = 0x0a;
-                break;
-            case 'b':
-            case 'B':
-                bitPattern = 0x0b;
-                break;
-            case 'c':
-            case 'C':
-                bitPattern = 0x0c;
-                break;
-            case 'd':
-            case 'D':
-                bitPattern = 0x0d;
-                break;
-            case 'e':
-            case 'E':
-                bitPattern = 0x0e;
-                break;
-            case 'f':
-            case 'F':
-                bitPattern = 0x0f;
-                break;
-            default:
-                // default case should never happen so abort during debugging
-                ASSERT(0);
-                bitPattern = 0;
-                break;
-        }
-
-        if ((i%2) == 0)
-        {
-            dest[i/2] = bitPattern << 4;
-        }
-        else
-        {
-            dest[i/2] |= bitPattern;
-        }
-    }
-} //AsciiHexToBinary
-
-
 DRIVER_ERROR DJ9xxVIP::VerifyPenInfo()
 {
     DRIVER_ERROR err=NO_ERROR;
@@ -816,7 +777,7 @@ DRIVER_ERROR DJ9xxVIP::ParsePenInfo(PEN_TYPE& ePen, BOOL QueryPrinter)
     DRIVER_ERROR err = SetPenInfo (str, QueryPrinter);
     ERRCHECK;
 
-	iNumMissingPens = 0;
+    iNumMissingPens = 0;
 
     // the first byte indicates how many pens are supported
     if ((str[0] >= '0') && (str[0] <= '9'))
@@ -832,10 +793,10 @@ DRIVER_ERROR DJ9xxVIP::ParsePenInfo(PEN_TYPE& ePen, BOOL QueryPrinter)
         return BAD_DEVICE_ID;
     }
 
-	if ((int) strlen (str) < (num_pens * 8))
-	{
-		return BAD_DEVICE_ID;
-	}
+    if ((int) strlen (str) < (num_pens * 8))
+    {
+        return BAD_DEVICE_ID;
+    }
 
 //  Aladdin style DevID
 
@@ -857,7 +818,7 @@ DRIVER_ERROR DJ9xxVIP::ParsePenInfo(PEN_TYPE& ePen, BOOL QueryPrinter)
         else if (penInfoBits[0] == 0xc0)
         {   // missing pen
             temp_pen1 = NO_PEN;
-			iNumMissingPens = 1;
+            iNumMissingPens = 1;
         }
         else
         {
@@ -882,7 +843,7 @@ DRIVER_ERROR DJ9xxVIP::ParsePenInfo(PEN_TYPE& ePen, BOOL QueryPrinter)
         else if (penInfoBits[0] == 0xc0)
         {   // missing pen
             ePen = temp_pen1;
-			iNumMissingPens = 1;
+            iNumMissingPens = 1;
         }
         else
         {
@@ -923,7 +884,12 @@ DRIVER_ERROR DJ9xxVIP::ParsePenInfo(PEN_TYPE& ePen, BOOL QueryPrinter)
     4 = Cyan
     5 = Meganta
     6 = Yellow
-    7 .. 63 = reserved for future use
+	7 = Cyan - low dye load 
+    8 = Magenta - low dye load 
+    9 = Yellow - low dye load (may never be used, but reserve space anyway) [def added Jun 3, 2002]
+    10 = gGK - two shades of grey plus black; g=light grey, G=medium Grey, K=black  [added Sep 12, 02]
+    11 .. 62 = reserved for future use
+    63=Unknown
 
     Bits 23 .. 19 (5 bits) describes the pen/supply id:
 
@@ -936,7 +902,14 @@ DRIVER_ERROR DJ9xxVIP::ParsePenInfo(PEN_TYPE& ePen, BOOL QueryPrinter)
     6 = Little John (Formerly M -- only for 6xx family)
     7 = Cyclone (Jupiter Pen)
     8 = Europa (Jupiter Ink)
-    31 = Other 9 .. 30 = reserved for future use
+    9 = Wax (pen/ink combo; k)  
+    10 = Pele (pen/ink combo; cmy)  
+    11 = Iris (pen/ink combo; kcm) 
+    12 = Zorro (pen/ink combo; k)    [def added Jun 27, 2002]
+    13 = Linus (k)  [def added Jun 27, 2002]
+    14 = Ash pen/ink combo; gGK)  [added Sep 12, 02] 
+    15 .. 30 = reserved for future use    [def added Jun 27, 2002]
+    31 = Other/Unknown  [def added Jun 27, 2002]
  */
 
     ePen = NO_PEN;
@@ -945,14 +918,14 @@ DRIVER_ERROR DJ9xxVIP::ParsePenInfo(PEN_TYPE& ePen, BOOL QueryPrinter)
     {
         AsciiHexToBinary (penInfoBits, p, 8);
 
-		if ((penInfoBits[1] & 0xf8) == 0xf8)
-		{
+        if ((penInfoBits[1] & 0xf8) == 0xf8)
+        {
 
-//			The high 5 bits in the 3rd and 4th nibble (second byte) identify the
-//			installed pen. If all 5 bits are on, user has installed an incompatible pen.
+//          The high 5 bits in the 3rd and 4th nibble (second byte) identify the
+//          installed pen. If all 5 bits are on, user has installed an incompatible pen.
 
-			return UNSUPPORTED_PEN;
-		}
+            return UNSUPPORTED_PEN;
+        }
 
         if ((penInfoBits[0] & 0x80) != 0x80)        // if Bit 31 is 0, this is not a pen
         {
@@ -962,10 +935,10 @@ DRIVER_ERROR DJ9xxVIP::ParsePenInfo(PEN_TYPE& ePen, BOOL QueryPrinter)
         switch (penColor)
         {
             case 0:
-			{
-				iNumMissingPens++;
+            {
+                iNumMissingPens++;
                 break;
-			}
+            }
             case 1:
                 ePen = BLACK_PEN;
                 break;
@@ -979,6 +952,10 @@ DRIVER_ERROR DJ9xxVIP::ParsePenInfo(PEN_TYPE& ePen, BOOL QueryPrinter)
                 {
                     ePen = MDL_BOTH;
                 }
+                else if (ePen == GREY_PEN)
+                {
+                    ePen = GREY_BOTH;
+                }
                 else
                 {
                     ePen = COLOR_PEN;
@@ -998,6 +975,14 @@ DRIVER_ERROR DJ9xxVIP::ParsePenInfo(PEN_TYPE& ePen, BOOL QueryPrinter)
                 {
                     ePen = MDL_BLACK_AND_COLOR_PENS;
                 }
+                else if (ePen == GREY_PEN)
+                {
+                    ePen = MDL_AND_GREY_PENS;
+                }
+                else if (ePen == GREY_BOTH)
+                {
+                    ePen = MDL_GREY_AND_COLOR_PENS;
+                }
                 else
                 {
                     ePen = MDL_PEN;
@@ -1005,7 +990,10 @@ DRIVER_ERROR DJ9xxVIP::ParsePenInfo(PEN_TYPE& ePen, BOOL QueryPrinter)
                 break;
             case 4:             // cyan pen
             case 5:             // magenta pen
-            case 6:             // yello pen
+            case 6:             // yellow pen
+            case 7:             // low dye load cyan pen
+            case 8:             // low dye load magenta pen
+            case 9:             // low dye load yellow pen
                 if (ePen == BLACK_PEN || ePen == BOTH_PENS)
                 {
                     ePen = BOTH_PENS;
@@ -1015,8 +1003,11 @@ DRIVER_ERROR DJ9xxVIP::ParsePenInfo(PEN_TYPE& ePen, BOOL QueryPrinter)
                     ePen = COLOR_PEN;
                 }
                 break;
+            case 10:
+                ePen = GREY_PEN;
+                break;
             default:
-                return UNSUPPORTED_PEN;
+                ePen = UNKNOWN_PEN;
         }
     }
     return NO_ERROR;
@@ -1226,14 +1217,14 @@ DISPLAY_STATUS DJ9xxVIP::ParseError(BYTE status_reg)
             return DISPLAY_TOP_COVER_OPEN;
         }
 
-		if (iVersion < 3)
-		{
-			pStr += 12;     // point to "feature state"
-		}
-		else if (iVersion < 5)
-		{
-			pStr += 14;
-		}
+        if (iVersion < 3)
+        {
+            pStr += 12;     // point to "feature state"
+        }
+        else if (iVersion < 5)
+        {
+            pStr += 14;
+        }
         else
         {
             pStr += 18;
@@ -1247,17 +1238,17 @@ DISPLAY_STATUS DJ9xxVIP::ParseError(BYTE status_reg)
             return DISPLAY_OUT_OF_PAPER;
         }
 
-		if (b1 == '0' && (b2 == 'c' || b2 == 'C'))		// 0C - PhotoTray Mismatch
-		{
+        if (b1 == '0' && (b2 == 'c' || b2 == 'C'))      // 0C - PhotoTray Mismatch
+        {
 
 /*
- *			PhotoTray is engaged, but requested paper size is larger than A6.
- *			It may also mean A6/Photo size is requested but photo tray is not engaged.
+ *          PhotoTray is engaged, but requested paper size is larger than A6.
+ *          It may also mean A6/Photo size is requested but photo tray is not engaged.
  */
 
-			DBG1("Photo Tray Mismatch [from Encoded DevID]\n");
-			return DISPLAY_PHOTOTRAY_MISMATCH;
-		}
+            DBG1("Photo Tray Mismatch [from Encoded DevID]\n");
+            return DISPLAY_PHOTOTRAY_MISMATCH;
+        }
 
 //      Paper Jam or Paper Stall
 
@@ -1274,6 +1265,7 @@ DISPLAY_STATUS DJ9xxVIP::ParseError(BYTE status_reg)
             return DISPLAY_ERROR_TRAP;
         }
 
+//      Job Cancelled (AIO printer turn idle after job canceled)
         if ((b1=='0') && (b2=='5'))     // 05 = CNCL state
         {
             DBG1("Printing Canceled [from Encoded DevID]\n");
@@ -1309,7 +1301,7 @@ DISPLAY_STATUS DJ9xxVIP::ParseError(BYTE status_reg)
 
         // DJ8XX doesn't go offline, so SELECT bit is set even when paper jammed.
         // See IO_defs.h
-		if (DEVICE_PAPER_JAMMED(status_reg))
+        if (DEVICE_PAPER_JAMMED(status_reg))
         {
             DBG1("Jammed [from status byte]\n");
             return DISPLAY_PAPER_JAMMED;
@@ -1319,11 +1311,11 @@ DISPLAY_STATUS DJ9xxVIP::ParseError(BYTE status_reg)
  *      missing, eventhough they support reserve mode printing. This causes us to
  *      report ERROR_TRAP message. Consequence is that we may not catch carriage
  *      stall, but should eventually result in time out.
-		if (DEVICE_IO_TRAP(status_reg))
-		{
+        if (DEVICE_IO_TRAP(status_reg))
+        {
             DBG1("Jammed or trapped [from status byte]\n");
             return DISPLAY_ERROR_TRAP;
-		}
+        }
  */
     }
 
@@ -1840,13 +1832,6 @@ BOOL DJ9xxVIP::PhotoTrayPresent
     BOOL bQueryPrinter
 )
 {
-#ifdef APDK_PROTO
-    if (!IOMode.bDevID)
-    {
-        return argPhotoTray;
-    }
-#endif
-
     // for phototray present == 8
     return ((PhotoTrayStatus(bQueryPrinter) & 8) == 8);
 } //PhotoTrayInstalled
@@ -1859,17 +1844,9 @@ PHOTOTRAY_STATE DJ9xxVIP::PhotoTrayEngaged
 {
 
 /*
- *	When you add any new printer models to this class, make sure that the printer
- *	has the phototray sensor and reports the phototray state correctly.
+ *  When you add any new printer models to this class, make sure that the printer
+ *  has the phototray sensor and reports the phototray state correctly.
  */
-
-#ifdef APDK_PROTO
-    if (!IOMode.bDevID)
-    {
-        return (PHOTOTRAY_STATE) argPhotoTray;
-    }
-#endif
-
     // for phototray present and engaged == 9
     return ((PHOTOTRAY_STATE) ((PhotoTrayStatus(bQueryPrinter) & 9) == 9));
 } //PhotoTrayEngaged
@@ -1898,7 +1875,7 @@ DRIVER_ERROR DJ9xxVIP::CheckInkLevel()
 /*
  *  Check for unknown device id version.
  */
-     
+
     if ((pSS->GetVIPVersion ()) > 5)
     {
         return NO_ERROR;
@@ -1919,9 +1896,9 @@ DRIVER_ERROR DJ9xxVIP::CheckInkLevel()
     //   meaning 2 pens, first field is head/supply for K
 
 /*
- *	VIPVersion = DevID Version + 1 - DevID Version no is 2 bytes following ;S:
- *	Version 00 and 01 report 12 bytes for status info
- *	Version 02 and onwards, report two additional bytes before pen info
+ *  VIPVersion = DevID Version + 1 - DevID Version no is 2 bytes following ;S:
+ *  Version 00 and 01 report 12 bytes for status info
+ *  Version 02 and onwards, report two additional bytes before pen info
  */
 
     if (pSS->GetVIPVersion () < 2)
@@ -1989,49 +1966,103 @@ DRIVER_ERROR DJ9xxVIP::CheckInkLevel()
     }
 
     pStr++;
+
+	BYTE    penInfoBits[4];
     BYTE    blackink = 0;
     BYTE    colorink = 0;
+    BYTE    photoink = 0;
+    BYTE    greyink = 0;
     for (int i = 0; i < numPens; i++, pStr += 8)
     {
-        if ((pStr[0] & 0x4) != 0x4) // if Bit 30 is 0, this is not ink supply
+        AsciiHexToBinary (penInfoBits, pStr, 8);
+
+        if ((penInfoBits[0] & 0x80) != 0x80)        // if Bit 31 is 0, this is not a pen
         {
             continue;
         }
-        BYTE    penColor = ((pStr[0] << 4) | pStr[1]) & 0x3F;
+        int penColor = penInfoBits[0] & 0x3F;
         switch (penColor)
         {
             case 1:
-                blackink = pStr[3] - '0';
+                blackink =  penInfoBits[1] & 0x7;
                 break;
             case 2:
-                colorink = pStr[3] - '0';
+                colorink =  penInfoBits[1] & 0x7;
                 break;
             case 3:
-                blackink = pStr[3] - '0';   // REVISIT: this is MDL pen
+                photoink =  penInfoBits[1] & 0x7;
+                break;
+            case 10:
+                greyink =  penInfoBits[1] & 0x7;
                 break;
             case 4:
             case 5:
             case 6:
-                colorink = pStr[3] - '0';   // REVISIT: these are C, M, Y respectively
+            case 7:
+            case 8:
+            case 9:
+                colorink = penInfoBits[1] & 0x7;   // REVISIT: these are C, M, Y respectively
                 break;
             default:
                 break;
         }
     }
-    if (blackink < 2 && colorink < 2)
+    if (blackink < 2 && colorink < 2 && photoink < 2 && greyink < 2)
     {
         return NO_ERROR;
     }
-    if (blackink > 1 && colorink > 1)
+    else if (blackink > 1 && colorink > 1 && photoink > 1)
+    {
+        return WARN_LOW_INK_COLOR_BLACK_PHOTO;
+    }
+    else if (greyink > 1 && colorink > 1 && photoink > 1)
+    {
+        return WARN_LOW_INK_COLOR_GREY_PHOTO;
+    }
+    else if (blackink > 1 && colorink > 1)
     {
         return WARN_LOW_INK_BOTH_PENS;
     }
-    if (blackink > 1)
+    else if (blackink > 1 && photoink > 1)
+    {
+        return WARN_LOW_INK_BLACK_PHOTO;
+    }
+    else if (greyink > 1 && colorink > 1)
+    {
+        return WARN_LOW_INK_COLOR_GREY;
+    }
+    else if (greyink > 1 && photoink > 1)
+    {
+        return WARN_LOW_INK_GREY_PHOTO;
+    }
+    else if (colorink > 1 && photoink > 1)
+    {
+        return WARN_LOW_INK_COLOR_PHOTO;
+    }
+    else if (blackink > 1)
     {
         return WARN_LOW_INK_BLACK;
     }
-    return WARN_LOW_INK_COLOR;
-
+    else if (colorink > 1)
+    {
+        return WARN_LOW_INK_COLOR;
+    }
+    else if (photoink > 1)
+    {
+        return WARN_LOW_INK_PHOTO;
+    }
+    else if (greyink > 1)
+    {
+        return WARN_LOW_INK_GREY;
+	}
+    else if (colorink > 1)
+    {
+        return WARN_LOW_INK_COLOR;
+    }
+	else
+	{
+		return NO_ERROR;
+	}
 } //CheckInkLevel
 
 APDK_END_NAMESPACE
