@@ -45,7 +45,7 @@ public:
     DJGenericVIP (SystemServices* pSS, BOOL proto = FALSE);
 
     DRIVER_ERROR VerifyPenInfo ();
-    virtual BOOL FullBleedCapable (PAPER_SIZE ps, float *xOverSpray, float *yOverSpray,
+    virtual BOOL FullBleedCapable (PAPER_SIZE ps, FullbleedType  *fbType, float *xOverSpray, float *yOverSpray,
                                    float *fLeftOverSpray, float *fTopOverSpray);
 	virtual BOOL UseGUIMode (PrintMode *pPrintMode);
 	virtual PAPER_SIZE MandatoryPaperSize ();
@@ -57,22 +57,6 @@ private:
 
 }; //DJGenericVIP
 
-#ifdef APDK_PROTO
-
-//ProtoDJGenericVIP
-/*
-******************************************************************************/
-class ProtoDJGenericVIP : public DJGenericVIP
-{
-public:
-    ProtoDJGenericVIP (ProtoServices* pSS);
-
-    DRIVER_ERROR ParsePenInfo (PEN_TYPE& ePen) {ePen=ProtoPenType; return NO_ERROR;}
-
-}; //ProtoDJGenericVIP
-
-#endif
-
 APDK_END_NAMESPACE
 
 #endif  // APDK_DJ_GENERIC_VIP_H
