@@ -89,7 +89,7 @@ void TErnieFilter::Filter1RawRow(unsigned char *currPtr, int rowWidthInPixels, u
 //    const unsigned int maxErrorForEightPixels = maxErrorForFourPixels / 2;
 
 //    int currPixel, lastPixel;
-    long currPixel, lastPixel;
+    uint32_t currPixel, lastPixel;
     bool lastPairAveraged = false;
     bool last2by2Averaged = false;
 
@@ -227,7 +227,7 @@ void TErnieFilter::Filter2RawRows(unsigned char *currPtr, unsigned char *upPtr,
     const unsigned int maxErrorForEightPixels = maxErrorForFourPixels / 2;
 
 //    int currPixel, upPixel, lastPixel;
-    long currPixel, upPixel, lastPixel;
+    uint32_t currPixel, upPixel, lastPixel;
     bool lastPairAveraged = false;
     bool last2by2Averaged = false;
 
@@ -1241,7 +1241,7 @@ void TErnieFilter::Filter3FilteredRows(unsigned char *row1Ptr, unsigned char *ro
     for (int pixelNum = 0; pixelNum < (fRowWidthInPixels-3);)  // Make sure we have four pixels to work with
     {
 //        int currPixel, upPixel;
-        long currPixel, upPixel;
+        uint32_t currPixel, upPixel;
         int R0, G0, B0, R1, G1, B1;
 
         if ((fPixelFilteredFlags[0][pixelNum] & e41si)
@@ -1539,7 +1539,7 @@ TErnieFilter::TErnieFilter(int rowWidthInPixels, pixelTypes pixelType, unsigned
     for (index = 0; index < 4; index++)
     {
 //        fRowBuf[index] = new unsigned int[rowWidthInPixels];
-        fRowBuf[index] = new unsigned long[rowWidthInPixels];
+        fRowBuf[index] = new uint32_t[rowWidthInPixels];
         ASSERT(fRowBuf[index]);
 
         //fRowPtr[index] = NULL;
@@ -1682,7 +1682,7 @@ void TErnieFilter::submitRowToFilter(unsigned char *rowPtr)
     // Now reformat the pixel data from 24 bit to 32 bit pixels
     int pixelIndex = 0;
 //    unsigned int *RowPtrDest = fRowBuf[fNumberOfBufferedRows];
-    unsigned long *RowPtrDest = fRowBuf[fNumberOfBufferedRows];
+    uint32_t *RowPtrDest = fRowBuf[fNumberOfBufferedRows];
     BYTE byte1 = 0;
     BYTE byte2 = 0;
     BYTE byte3 = 0;
@@ -1835,7 +1835,7 @@ void TErnieFilter::WriteBlockPixels(void)
             if (currentFlags & eTopLeftOfBlocks) // Avoids doing a lot of checks if nothing is set.
             {
 //                unsigned int pixel;
-                unsigned long pixel;
+                uint32_t pixel;
                 //  The three possible scenerios are:
                 //  1: No top left of block bits are set.
                 //  2: 1 top left block bit is set.
