@@ -84,7 +84,7 @@ int hpijs_set_context(UXServices *pSS)
    }
 
    /* Map ghostscript paper size to APDK paper size. */
-   pSS->MapPaperSize(pSS->PaperWidth, pSS->PaperHeight, pSS->Model); 
+   pSS->MapPaperSize(pSS->PaperWidth, pSS->PaperHeight); 
 
    /* Do duplex stuff now, since we have a valid print mode. */
    if (pSS->Duplex && !pSS->Tumble)
@@ -198,26 +198,26 @@ int hpijs_set_cb (void *set_cb_data, IjsServerCtx *ctx, IjsJobId job_id,
    }
    else if (!strcmp (key, "DeviceModel"))
    {
-      /* Map device model to model number. */
-      pSS->MapModel(svalue);
-
-      if (pSS->Model == -1)
+      if ((r = pSS->pPC->SelectDevice(svalue)) != NO_ERROR)
       {
-         bug("unable to set DeviceModel=%s\n", svalue);
-         status = -1;
+         /* OfficeJet LX is not very unique, do separate check here. */
+         if (!strncmp(svalue,"OfficeJet", 10))
+	    r = pSS->pPC->SelectDevice("DESKJET 540");
       }
 
-      if ((r = pSS->pPC->SelectDevice((PRINTER_TYPE)pSS->Model)) != NO_ERROR)
-      {
-         bug("unable to set device=%d, err=%d\n", pSS->Model, r);
-         status = -1;
-      }
-      else
+      if (r == NO_ERROR)
       {
+         pSS->Model = 1;
+
          /* Got a valid device class, let's set some print mode defaults. */
          BOOL        bDevText;
          pSS->pPC->GetPrintModeSettings ((QUALITY_MODE)pSS->Quality, (MEDIATYPE)pSS->MediaType, (COLORMODE)pSS->ColorMode, bDevText);
       }
+      else
+      {
+         bug("unable to set device=%s, err=%d\n", svalue, r);
+         status = -1;
+      }
    }
    else if ((strcmp (key, "PS:Duplex") == 0) || (strcmp (key, "Duplex") == 0))
    {
@@ -336,7 +336,7 @@ int hpijs_get_cb(void *get_cb_data, IjsServerCtx *ctx, IjsJobId job_id, const ch
    }
    else if (!strcmp (key, "DeviceModel"))
    {
-      return snprintf(value_buf, value_size, "%s", pSS->pPC->PrintertypeToString((PRINTER_TYPE)pSS->Model));
+      return snprintf(value_buf, value_size, "%s", pSS->pPC->PrinterModel());
    }
    else if (!strcmp (key, "Quality:Quality"))
    {
@@ -515,7 +515,7 @@ int main(int argc, char *argv[])
          bug("EffResX=%d, EffResY=%d, InPixelsPerRow=%d, OutPixelsPerRow=%d\n", 
             pSS->pPC->EffectiveResolutionX(), pSS->pPC->EffectiveResolutionY(), 
             pSS->pPC->InputPixelsPerRow(), pSS->pPC->OutputPixelsPerRow());
-         bug("model=%s\n", pSS->pPC->PrintertypeToString(pSS->pPC->SelectedDevice()));
+         bug("device=%s\n", pSS->pPC->PrinterModel());
 #endif
       } // pSS->FirstRaster
 
@@ -555,8 +555,10 @@ int main(int argc, char *argv[])
    {
       if (pSS->BackPage)
       {
-         /* Send extra blank line & newpage to eject the page. (for VIP printers). */ 
-         for (int i = 0; i < 201; i++)
+         /* Send extra blank line & newpage to eject the page. (for VIP printers). */
+         /* For malibu send enough blank lines to cause at least two blank rasters in Job::sendrasters(). 5/1/03, des */
+         //         for (int i = 0; i < 201; i++)
+         for (int i = 0; i < 401; i++)
             pSS->pJob->SendRasters((unsigned char *)0);
          pSS->pJob->NewPage();
       }
