@@ -28,21 +28,12 @@
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 \*****************************************************************************/
 
-
-#ifdef APDK_PROTO
-#include "../../newharness/Options.h"
-extern Options opt;
-#endif
-
 #include "header.h"
 #include "halftoner.h"
 #include "colormatch.h"
 #include "scaler_open.h"
 #include "scaler_prop.h"
 
-
-
-#ifndef APDK_PROTO
 APDK_BEGIN_NAMESPACE
 extern Halftoner* Create_Halftoner( SystemServices* pSys, PrintMode* pPM,
                 unsigned int iInputWidth, unsigned int iNumRows[], unsigned int HiResFactor,
@@ -55,14 +46,6 @@ extern ColorMatcher* Create_ColorMatcher( SystemServices* pSys,
 extern BOOL ProprietaryImaging();
 extern BOOL ProprietaryScaling();
 APDK_END_NAMESPACE
-#else
-#include "../proprietary/colormatcher_prop.h"
-#include "colormatcher_open.h"
-#include "../open/halftoner_open.h"
-#include "../proprietary/halftoner_prop.h"
-extern BOOL ProprietaryImaging();
-extern BOOL ProprietaryScaling();
-#endif
 
 APDK_BEGIN_NAMESPACE
 
@@ -214,27 +197,12 @@ DRIVER_ERROR Job::SetupHalftoning(HALFTONING_ALGORITHM eHT)
     BOOL usematrix = (eHT == MATRIX);
 // but this is overridden in speed-optimized builds
 // we also can simulate the build-switch at runtime in the test harness
-#ifdef APDK_PROTO
-    if (opt.GetargSpeedOptimize())
-        usematrix = TRUE;
-    // else leave it as it was in printmode
-#else
 #ifdef APDK_OPTIMIZE_FOR_SPEED
         usematrix = TRUE;
 #endif
-#endif
 
-#ifdef APDK_PROTO
-    if (!ProprietaryImaging())
-        pHalftoner = new Halftoner_Open(thePrintContext->pSS, CurrentMode,
-                                  OutputWidth, numrows,ResBoost,usematrix);
-    else
-        pHalftoner = new Halftoner_Prop(thePrintContext->pSS, CurrentMode,
-                                 OutputWidth, numrows,ResBoost,usematrix);
-#else
     pHalftoner = Create_Halftoner(thePrintContext->pSS, CurrentMode,
                                   OutputWidth, numrows,ResBoost,usematrix);
-#endif
 
 
     NEWCHECK(pHalftoner);
@@ -250,26 +218,8 @@ DRIVER_ERROR Job::SetupColorMatching()
     if (pResSynth)      // if 2X scaling happens before ColorMatching
         cmWidth *= 2;
 
-#ifdef APDK_PROTO
-    if (opt.GetargSpeedOptimize())
-        // open colormatching is faster than proprietary, so use it even in proprietary
-        pColorMatcher = new ColorMatcher_Open(thePrintContext->pSS, CurrentMode->cmap,
-                                              CurrentMode->dyeCount, cmWidth);
-    else if (!ProprietaryImaging())
-        pColorMatcher = new ColorMatcher_Open(thePrintContext->pSS, CurrentMode->cmap,
-                                        CurrentMode->dyeCount, cmWidth);
-    else pColorMatcher = new ColorMatcher_Prop(thePrintContext->pSS, CurrentMode->cmap,
-                                        CurrentMode->dyeCount, cmWidth);
-#else   // production code
-#ifdef APDK_OPTIMIZE_FOR_SPEED
-    // open colormatching is faster than proprietary, so use it even in proprietary
-    pColorMatcher = new ColorMatcher_Open(thePrintContext->pSS, CurrentMode->cmap,
-                                        CurrentMode->dyeCount, cmWidth);
-#else   // get the open or prop depending on fileset
     pColorMatcher = Create_ColorMatcher(thePrintContext->pSS, CurrentMode->cmap,
                                         CurrentMode->dyeCount, cmWidth);
-#endif  // APDK_OPTIMIZE_FOR_SPEED
-#endif  // APDK_PROTO
 
     NEWCHECK(pColorMatcher);
     return pColorMatcher->constructor_error;
@@ -561,14 +511,9 @@ DRIVER_ERROR Job::InitScaler()
 //  or printer-res=300 and scale<2.33 (i.e. original-res<133)
     BOOL RSok;
     BOOL speedy=FALSE;
-
-#ifdef APDK_PROTO
-    speedy = opt.GetargSpeedOptimize();
-#else
 #ifdef APDK_OPTIMIZE_FOR_SPEED
     speedy = TRUE;
 #endif  // APDK_OPTIMIZE_FOR_SPEED
-#endif  // APDK_PROTO
     if (speedy)
     {
         RSok = FALSE;
@@ -612,13 +557,10 @@ DRIVER_ERROR Job::InitScaler()
 // first give ResSynth a factor of 2, which is all it really does anyway.
 
 // Scaler_Prop only operates on RGB, so it doesn't need the last two parameters
-#ifdef APDK_PROTO
-    pResSynth = new Scaler_Prop(pSS,InputWidth,2,1);
-#else
     pResSynth = Create_Scaler(pSS,InputWidth,2,1,
                               TRUE,     // as if VIP since it is working on RGB only at this phase
                               3);       // 3 bytes per pixel
-#endif
+
     NEWCHECK(pResSynth);
     if (pResSynth->constructor_error != NO_ERROR)
     {
