@@ -34,16 +34,31 @@
 #include "header.h"
 #include "io_defs.h"
 #include "ljcolor.h"
-
-#ifdef APDK_PROTO
+#include "printerproxy.h"
 #include "resources.h"
-#endif
 
 APDK_BEGIN_NAMESPACE
 
 extern uint32_t ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
 extern uint32_t ulMapGRAY_K_6x6x1[9 * 9 * 9];
 
+//! LJColorProxy
+/*!
+******************************************************************************/
+static class LJColorProxy : public PrinterProxy
+{
+public:
+    LJColorProxy() : PrinterProxy(
+        "ColorLaser",                   // family name
+        "hp color LaserJet\0"           // models
+		"hp business inkjet 3000\0"     // business inkjet 3000 series
+#ifdef APDK_MLC_PRINTER
+#endif
+    ) {}
+    inline Printer* CreatePrinter(SystemServices* pSS) const { return new LJColor(pSS); }
+} LJColorProxy;
+
+
 LJColor::LJColor (SystemServices* pSS, int numfonts, BOOL proto)
     : Printer(pSS, numfonts, proto)
 {
@@ -62,11 +77,13 @@ LJColor::LJColor (SystemServices* pSS, int numfonts, BOOL proto)
     pMode[SPECIALMODE_INDEX+2] = new LJColorKDraftMode ();
     ModeCount = 5;
 
+
     CMYMap = NULL;
     m_bJobStarted = FALSE;
 #ifdef  APDK_AUTODUPLEX
     m_bRotateBackPage = FALSE;  // Lasers don't require back side image to be rotated
-
+#endif
+#ifdef APDK_EXTENDED_MEDIASIZE
     pMode[SPECIALMODE_INDEX+3] = new LJColorPlainBestMode ();
     ModeCount = 6;
 #endif
@@ -97,8 +114,8 @@ LJColor::~LJColor ()
 LJColorKDraftMode::LJColorKDraftMode ()
 : GrayMode (ulMapVOLTAIRE_CCM_K)
 {
-	theQuality = qualityDraft;
-	pmQuality  = QUALITY_DRAFT;
+    theQuality = qualityDraft;
+    pmQuality  = QUALITY_DRAFT;
     pmColor    = GREY_K;
 #ifdef APDK_AUTODUPLEX
     bDuplexCapable = TRUE;
@@ -155,7 +172,6 @@ LJColor600DPIMode::LJColor600DPIMode ()
     ResolutionX[0] = 600;
     ResolutionY[0] = 600;
     BaseResX = BaseResY = 600;
-
     Config.bColorImage = FALSE;
 	theQuality = qualityPresentation;
     bFontCapable = TRUE;
@@ -166,7 +182,7 @@ LJColor600DPIMode::LJColor600DPIMode ()
 #endif
 }
 
-#ifdef  APDK_AUTODUPLEX
+#ifdef  APDK_EXTENDED_MEDIASIZE
 LJColorPlainBestMode::LJColorPlainBestMode ()
 : PrintMode (NULL)
 {
@@ -189,9 +205,9 @@ HeaderLJColor::HeaderLJColor (Printer* p, PrintContext* pc)
 { }
 
 DRIVER_ERROR HeaderLJColor::Send ()
-{   
-	DRIVER_ERROR err;
-	char	uom[12];
+{
+    DRIVER_ERROR err;
+    char    uom[12];
 
     COLORMODE       eC = COLOR;
     MEDIATYPE       eM;
@@ -211,54 +227,54 @@ DRIVER_ERROR HeaderLJColor::Send ()
     {
 
 /*
- *	    Configure image data - ESC*v#W - # = 6 bytes
+ *      Configure image data - ESC*v#W - # = 6 bytes
  *      02 - RGB colorspace (00 - Device RGB)
- *	    03 - Direct pixel
- *	    08 - bits per index - ignored for direct pixel
- *	    08, 08, 08 - bits per primary each
+ *      03 - Direct pixel
+ *      08 - bits per index - ignored for direct pixel
+ *      08, 08, 08 - bits per primary each
  */
 
-	    err = thePrinter->Send ((const BYTE *) "\033*v6W\00\03\010\010\010\010", 11);
-	    ERRCHECK;
+        err = thePrinter->Send ((const BYTE *) "\033*v6W\00\03\010\010\010\010", 11);
+        ERRCHECK;
 
-//	    Continues tone dither
-//	    Logical operation - 0
+//      Continues tone dither
+//      Logical operation - 0
 
-//	    err = thePrinter->Send ((const BYTE *) "\033*t18J\033*l204O", 13);
-	    err = thePrinter->Send ((const BYTE *) "\033*t18J", 6);
+//      err = thePrinter->Send ((const BYTE *) "\033*t18J\033*l204O", 13);
+        err = thePrinter->Send ((const BYTE *) "\033*t18J", 6);
 
-	    ERRCHECK;
+        ERRCHECK;
 
 /*
- *	    Driver Configuration Command - ESC*#W - # = 3 bytes
- *	    device id - 6 = color HP LaserJet Printer
- *	    func index - 4 = Select Colormap
- *	    argument - 2   = Vivid Graphics
+ *      Driver Configuration Command - ESC*#W - # = 3 bytes
+ *      device id - 6 = color HP LaserJet Printer
+ *      func index - 4 = Select Colormap
+ *      argument - 2   = Vivid Graphics
  */
 
-	    err = thePrinter->Send ((const BYTE *) "\033*o3W\06\04\06", 8);
-	    ERRCHECK;
+        err = thePrinter->Send ((const BYTE *) "\033*o3W\06\04\06", 8);
+        ERRCHECK;
 
 /*
- *	    Program color palette entries
+ *      Program color palette entries
  */
-	    err = thePrinter->Send ((const BYTE *) "\033*v255A\033*v255B\033*v255C\033*v0I", 26);
-	    ERRCHECK;
+        err = thePrinter->Send ((const BYTE *) "\033*v255A\033*v255B\033*v255C\033*v0I", 26);
+        ERRCHECK;
 
-	    err = thePrinter->Send ((const BYTE *) "\033*v255A\033*v0B\033*v0C\033*v6I", 22);
-	    ERRCHECK;
-	    err = thePrinter->Send ((const BYTE *) "\033*v0A\033*v255B\033*v0C\033*v5I", 22);
-	    ERRCHECK;
-	    err = thePrinter->Send ((const BYTE *) "\033*v0A\033*v0B\033*v255C\033*v3I", 22);
-	    ERRCHECK;
-	    err = thePrinter->Send ((const BYTE *) "\033*v255A\033*v255B\033*v0C\033*v4I", 24);
-	    ERRCHECK;
-	    err = thePrinter->Send ((const BYTE *) "\033*v255A\033*v0B\033*v255C\033*v2I", 24);
-	    ERRCHECK;
-	    err = thePrinter->Send ((const BYTE *) "\033*v0A\033*v255B\033*v255C\033*v1I", 24);
-	    ERRCHECK;
-	    err = thePrinter->Send ((const BYTE *) "\033*v0A\033*v0B\033*v0C\033*v7I", 20);
-	    ERRCHECK;
+        err = thePrinter->Send ((const BYTE *) "\033*v255A\033*v0B\033*v0C\033*v6I", 22);
+        ERRCHECK;
+        err = thePrinter->Send ((const BYTE *) "\033*v0A\033*v255B\033*v0C\033*v5I", 22);
+        ERRCHECK;
+        err = thePrinter->Send ((const BYTE *) "\033*v0A\033*v0B\033*v255C\033*v3I", 22);
+        ERRCHECK;
+        err = thePrinter->Send ((const BYTE *) "\033*v255A\033*v255B\033*v0C\033*v4I", 24);
+        ERRCHECK;
+        err = thePrinter->Send ((const BYTE *) "\033*v255A\033*v0B\033*v255C\033*v2I", 24);
+        ERRCHECK;
+        err = thePrinter->Send ((const BYTE *) "\033*v0A\033*v255B\033*v255C\033*v1I", 24);
+        ERRCHECK;
+        err = thePrinter->Send ((const BYTE *) "\033*v0A\033*v0B\033*v0C\033*v7I", 20);
+        ERRCHECK;
     }
 
     sprintf (uom, "\033*r%dS", thePrintContext->OutputPixelsPerRow ());
@@ -267,23 +283,23 @@ DRIVER_ERROR HeaderLJColor::Send ()
 
     err = Graphics ();     // start raster graphics and set compression mode
 
-	return err;
+    return err;
 }
 
 DRIVER_ERROR HeaderLJColor::StartSend ()
 {
     DRIVER_ERROR err;
-	char	res[64];
-	int		iRes;
+    char    res[64];
+    int     iRes;
 
-	iRes = thePrintContext->EffectiveResolutionY ();
+    iRes = thePrintContext->EffectiveResolutionY ();
 
     err = thePrinter->Send ((const BYTE*)UEL,sizeof(UEL));
     ERRCHECK;
 
-	sprintf (res, "@PJL SET PAGEPROTECT=AUTO@PJL SET RESOLUTION=%d\015\012", iRes);
-	err = thePrinter->Send ((const BYTE *) res, strlen (res));
-	ERRCHECK;
+    sprintf (res, "@PJL SET PAGEPROTECT=AUTO@PJL SET RESOLUTION=%d\015\012", iRes);
+    err = thePrinter->Send ((const BYTE *) res, strlen (res));
+    ERRCHECK;
 
     if (thePrinter->IOMode.bStatus)
     {
@@ -340,12 +356,12 @@ DRIVER_ERROR HeaderLJColor::StartSend ()
     err = thePrinter->Send ((const BYTE *) res, strlen (res));		// Source
     ERRCHECK;
 
-//	Media size, vertical spacing between lines and top margin
+//  Media size, vertical spacing between lines and top margin
 
-	memcpy (res, mediasize, mscount - 1);
-	strcpy (res+mscount-1, "a8c0E");
-	err = thePrinter->Send ((const BYTE *) res, strlen (res));
-	ERRCHECK;
+    memcpy (res, mediasize, mscount - 1);
+    strcpy (res+mscount-1, "a8c0E");
+    err = thePrinter->Send ((const BYTE *) res, strlen (res));
+    ERRCHECK;
 
 	sprintf (res, "\033*t%dR\033&u%dD", iRes, iRes);
     err=thePrinter->Send ((const BYTE*) res, strlen (res));
@@ -385,12 +401,10 @@ DRIVER_ERROR HeaderLJColor::Graphics ()
     }
     else
     {
-//        err = thePrinter->Send ((const BYTE*) "\033*b0M", 5);	// No compression
         err = thePrinter->Send ((const BYTE*) "\033*b3M", 5);
-
     }
 
-	return err;
+    return err;
 }
 
 DRIVER_ERROR HeaderLJColor::EndJob ()
@@ -404,7 +418,7 @@ DRIVER_ERROR HeaderLJColor::EndJob ()
         err = thePrinter->Send ((const BYTE *) szBuff, strlen (szBuff));
         ERRCHECK;
     }
-    strcpy (szBuff, "\033%%-12345X");
+    strcpy (szBuff, "\033%-12345X");
     err = thePrinter->Send ((const BYTE *) szBuff, strlen (szBuff));
 
     return err;
@@ -412,8 +426,8 @@ DRIVER_ERROR HeaderLJColor::EndJob ()
 
 DRIVER_ERROR HeaderLJColor::FormFeed ()
 {
-	((LJColor *)thePrinter)->bFGColorSet = FALSE;
-	((LJColor *)thePrinter)->m_iYPos = 0;
+    ((LJColor *)thePrinter)->bFGColorSet = FALSE;
+    ((LJColor *)thePrinter)->m_iYPos = 0;
 
     return (thePrinter->Send ((const BYTE *) "\014", 1));
 }
@@ -429,20 +443,20 @@ DRIVER_ERROR HeaderLJColor::SendCAPy (unsigned int iAbsY)
 
 DRIVER_ERROR LJColor::Encapsulate (const BYTE *pRasterData, DWORD size, BOOL bLastPlane)
 {
-	char	szScratchStr[16];
-	DRIVER_ERROR	err;
+    char    szScratchStr[16];
+    DRIVER_ERROR    err;
     m_iYPos++;
-	if (bFGColorSet == FALSE)
-	{
-		Send ((const BYTE *) "\033*v7S", 5);
-		bFGColorSet = TRUE;
-	}
-	sprintf (szScratchStr, "\033*b%uW", size);
-	err = Send ((const BYTE *) szScratchStr, strlen (szScratchStr));
-	if (err == NO_ERROR)
-	{
-		err = Send (pRasterData, size);
-	}
+    if (bFGColorSet == FALSE)
+    {
+        Send ((const BYTE *) "\033*v7S", 5);
+        bFGColorSet = TRUE;
+    }
+    sprintf (szScratchStr, "\033*b%uW", size);
+    err = Send ((const BYTE *) szScratchStr, strlen (szScratchStr));
+    if (err == NO_ERROR)
+    {
+        err = Send (pRasterData, size);
+    }
 
 /*
  *  Printers with low memory (64 MB or less) can run out of memory during decompressing
@@ -458,7 +472,7 @@ DRIVER_ERROR LJColor::Encapsulate (const BYTE *pRasterData, DWORD size, BOOL bLa
         err = Send ((const BYTE *) "\033*rC\033*r1A\033*b3M", 14);
     }
 
-	return err;
+    return err;
 }
 
 DRIVER_ERROR LJColor::SkipRasters (int nBlankRasters)
@@ -495,55 +509,8 @@ DRIVER_ERROR LJColor::VerifyPenInfo()
         return err;
     }
 
-	ePen = BOTH_PENS;
-	return NO_ERROR;
-/*
-    err = ParsePenInfo(ePen);
-
-    if(err == UNSUPPORTED_PEN) // probably Power Off - pens couldn't be read
-    {
-        if (pSS->BusyWait((DWORD)2000) == JOB_CANCELED)
-        {
-            return JOB_CANCELED;
-        }
-
-        err = ParsePenInfo(ePen);
-    }
-
-    ERRCHECK;
-
-    // check for the normal case
-    if (ePen == BLACK_PEN)
-    {
-        return NO_ERROR;
-    }
-
-    while (ePen != BLACK_PEN)
-    {
-
-        switch (ePen)
-        {
-            case BLACK_PEN:
-                continue;
-            case NO_PEN:
-            default:
-                pSS->DisplayPrinterStatus(DISPLAY_NO_PENS);
-                break;
-        }
-
-        if (pSS->BusyWait(500) == JOB_CANCELED)
-        {
-            return JOB_CANCELED;
-        }
-
-        err =  ParsePenInfo (ePen);
-        ERRCHECK;
-    }
-
-    pSS->DisplayPrinterStatus (DISPLAY_PRINTING);
-
+    ePen = BOTH_PENS;
     return NO_ERROR;
-*/
 }
 
 DRIVER_ERROR LJColor::ParsePenInfo(PEN_TYPE& ePen, BOOL QueryPrinter)
@@ -552,14 +519,14 @@ DRIVER_ERROR LJColor::ParsePenInfo(PEN_TYPE& ePen, BOOL QueryPrinter)
 //    DRIVER_ERROR err = SetPenInfo(str, QueryPrinter);
 //    ERRCHECK;
 
-	ePen = BOTH_PENS;
+    ePen = BOTH_PENS;
 
     return NO_ERROR;
 }
 
 Compressor* LJColor::CreateCompressor (unsigned int RasterSize)
 {
-	bFGColorSet = FALSE;
+    bFGColorSet = FALSE;
     if (bGrey_K)
         return new Mode2 (pSS, RasterSize);
 
@@ -661,11 +628,11 @@ DISPLAY_STATUS LJColor::ParseError(BYTE status_reg)
 
     if ((iErrorCode / 1000) == 42 || iErrorCode == 40022)
     {
-		DBG1("Paper Jammed\n");
-		return DISPLAY_PAPER_JAMMED;
-	}
+        DBG1("Paper Jammed\n");
+        return DISPLAY_PAPER_JAMMED;
+    }
 
-	if (iErrorCode > 40049 && iErrorCode < 41000)
+    if (iErrorCode > 40049 && iErrorCode < 41000)
     {
         DBG1("IO trap\n");
         return DISPLAY_ERROR_TRAP;
