@@ -31,11 +31,13 @@
 
 #include "config.h"
 
+#include "global_types.h"
+
 #ifdef APDK_DJ8x5
 
 APDK_BEGIN_NAMESPACE
 
-unsigned long ulMapPhobosDraft[ 9 * 9 * 9 ] =
+uint32_t ulMapPhobosDraft[ 9 * 9 * 9 ] =
 {
 4294967040UL, 3034836992UL, 2094464768UL, 1439104512UL,  867696128UL,  582024704UL,
  312933888UL,   94633472UL,   10551040UL, 4289449216UL, 3469671936UL, 2093612544UL,
@@ -161,7 +163,7 @@ unsigned long ulMapPhobosDraft[ 9 * 9 * 9 ] =
  922746880UL,  520093696UL,          0
 };
 
-unsigned long ulMapPhobosPlainNormal[9 * 9 * 9] =
+uint32_t ulMapPhobosPlainNormal[9 * 9 * 9] =
 {
 4294967040UL, 2681863936UL, 1723662080UL, 1286209280UL, 1033699072UL,  831782656UL,
  630062848UL,  377552640UL,    7077632UL, 4289394944UL, 3250716416UL, 1940848384UL,
@@ -288,7 +290,7 @@ unsigned long ulMapPhobosPlainNormal[9 * 9 * 9] =
 };
 
 /*
-unsigned long ulMapPhobosPhoto[9 * 9 * 9] =
+uint32_t ulMapPhobosPhoto[9 * 9 * 9] =
 {
 3503543808UL, 3100498688UL, 2495668736UL, 1890903552UL, 1370285568UL,  916973056UL,
  514057728UL,  161604864UL,   10610176UL, 3718890240UL, 2964445952UL, 2545080832UL,
