@@ -37,13 +37,9 @@
 //
 // ** Printer CLASS **
 
-#ifndef APDK_PROTO
 APDK_BEGIN_NAMESPACE
 extern BYTE* GetHTBinary();
 APDK_END_NAMESPACE
-#else
-extern int argProprietaryImaging;
-#endif
 
 APDK_BEGIN_NAMESPACE
 
@@ -521,7 +517,7 @@ DRIVER_ERROR Printer::Send
                 pBuffer = pSendBuffer;
                 dwSendSize = iCurrBuffSize;
             }
-    }
+		}
 #endif
 
     // initialize our 'residual' to the full send size
@@ -571,7 +567,7 @@ DRIVER_ERROR Printer::Send
 
                 BYTE b1=*tmpStr++;
                 BYTE b2=*tmpStr++;
-                if ((b1=='0') && (b2=='5') && iVersion <= 5)     // 05 = cancel
+                if (((b1=='0') && (b2=='5')) && iVersion <= 5)     // 05 = cancel
                 {
                     cancelcheck=TRUE;
                 }
@@ -1024,22 +1020,9 @@ PrintMode::PrintMode
     Config.bColorImage = TRUE;
     Config.bCompress = TRUE;
     Config.eHT = FED;
-
-#ifdef APDK_PROTO
-    if (!argProprietaryImaging)
-    {
-        BlackFEDTable = (BYTE*) HTBinary_open;
-        ColorFEDTable = (BYTE*) HTBinary_open;
-    }
-    else
-    {
-        BlackFEDTable = (BYTE*) HTBinary_prop;
-        ColorFEDTable = (BYTE*) HTBinary_prop;
-    }
-#else
     BlackFEDTable = GetHTBinary();
     ColorFEDTable = GetHTBinary();
-#endif
+
 
     // set for most common cases
     bFontCapable = TRUE;
