@@ -51,7 +51,7 @@ public:
 
     virtual BOOL UseGUIMode (PrintMode* pPrintMode);
     PAPER_SIZE    MandatoryPaperSize ();
-    virtual BOOL FullBleedCapable (PAPER_SIZE ps, float *xOverSpray, float *yOverSpray,
+    virtual BOOL FullBleedCapable (PAPER_SIZE ps, FullbleedType  *fbType, float *xOverSpray, float *yOverSpray,
                                    float *fLeftOverSpray, float *fTopOverSpray)
     {
         *xOverSpray = (float) 0.12;
@@ -62,6 +62,15 @@ public:
         if (fTopOverSpray)
             *fTopOverSpray  = (float) 0.03;
 
+		if (ps == PHOTO_SIZE || ps == A6_WITH_TEAR_OFF_TAB)
+		{
+			*fbType = fullbleed4EdgeAllMedia;
+		}
+		else
+		{
+			*fbType = fullbleed3EdgeAllMedia;
+		}
+
         return TRUE;
     }
 
@@ -77,7 +86,7 @@ public:
     PSP100Mode ();
 }; //PSP100Mode
 
-#ifdef APDK_AUTODUPLEX
+#ifdef APDK_EXTENDED_MEDIASIZE
 //PSP1002400Mode
 /*
 ******************************************************************************/
@@ -99,21 +108,6 @@ public:
 }; //GrayModePSP100
 
 
-#ifdef APDK_PROTO
-//ProtoPSP100
-/*
-******************************************************************************/
-class ProtoPSP100 : public PSP100
-{
-public:
-    ProtoPSP100 (ProtoServices* pSS);
-
-    DRIVER_ERROR ParsePenInfo(PEN_TYPE& ePen) { ePen=ProtoPenType; return NO_ERROR; }
-
-}; //ProtoPSP100
-
-#endif
-
 APDK_END_NAMESPACE
 
 #endif  // APDK_PSP100_H
