@@ -33,76 +33,7 @@
 // of supported devices from the system.
 
 #include "header.h"
-
-#ifdef APDK_DJ350
-#include "dj6xx.h"
-#include "dj600.h"
-#include "dj350.h"
-#endif
-#ifdef APDK_DJ400
-#include "dj400.h"
-#endif
-#if defined(APDK_DJ6xx) || defined(APDK_DJ6xxPhoto)
-#include "dj6xx.h"
-#include "dj660.h"
-#include "dj690.h"
-#endif
-#ifdef APDK_DJ600
-#include "dj6xx.h"
-#include "dj600.h"
-#endif
-#ifdef APDK_DJ540
-#include "dj6xx.h"
-#include "dj540.h"
-#endif
-#ifdef APDK_DJ630
-#include "dj630.h"
-#endif
-#ifdef APDK_DJ8xx
-#include "dj8xx.h"
-#endif
-#ifdef APDK_DJ8x5
-#include "dj8x5.h"
-#endif
-#ifdef APDK_DJ850
-#include "dj850.h"
-#endif
-#ifdef APDK_DJ890
-#include "dj890.h"
-#endif
-#ifdef APDK_DJ9xx
-#include "dj9xx.h"
-#endif
-#if defined(APDK_DJ9xxVIP) || defined(APDK_PSP100)
-#include "dj9xxvip.h"
-#endif
-#ifdef APDK_DJGENERICVIP
-#include "djgenericvip.h"
-#endif
-#ifdef APDK_PSP100
-#include "psp100.h"
-#endif
-#ifdef APDK_DJ3320
-#include "dj3320.h"
-#endif
-#if defined(APDK_APOLLO2XXX) || defined(APDK_APOLLO21XX) || defined(APDK_APOLLO2560)
-#include "apollo2xxx.h"
-#endif
-#ifdef APDK_APOLLO21XX
-#include "apollo21xx.h"
-#endif
-#ifdef APDK_APOLLO2560
-#include "apollo2560.h"
-#endif
-#ifdef APDK_LJMONO
-#include "ljmono.h"
-#endif
-#ifdef APDK_LJCOLOR
-#include "ljcolor.h"
-#endif
-#ifdef APDK_PSCRIPT
-#include "pscript.h"
-#endif
+#include "printerfactory.h"
 
 APDK_BEGIN_NAMESPACE
 
@@ -397,168 +328,17 @@ DRIVER_ERROR DeviceRegistry::InstantiatePrinter(Printer*& p, SystemServices* pSS
 // Instantiate a printer object and return a pointer p based on the previously
 // set 'device' variable
 {
-    p=NULL;
+    //ASSERT(p == NULL);  // if it's not then we're going to loose memory
 
-DBG1("DR::InstantiateGeneral: device = ");
-
-    switch(device) {
-
-#ifdef APDK_DJ350
-        case (eDJ350):
-            DBG1("DJ350\n");
-            p = new DJ350 (pSS);
-            break;
-#endif
-
-#ifdef APDK_DJ400
-        case(eDJ400):
-                     DBG1("DJ400\n");
-                     p=new DJ400(pSS);
-                     break;
-#endif
-
-#ifdef APDK_DJ540
-        case(eDJ540):
-                     DBG1("DJ540\n");
-                     p=new DJ540(pSS);
-                     break;
-#endif
-
-#ifdef APDK_DJ600
-        case(eDJ600):
-                     DBG1("DJ600\n");
-                     p=new DJ600(pSS);
-                     break;
-#endif
-
-#ifdef APDK_DJ6xx
-        case(eDJ6xx):
-                     DBG1("DJ6xx\n");
-                     p=new DJ660(pSS);
-                     break;
-#endif
-
-#ifdef APDK_DJ6xxPhoto
-        case(eDJ6xxPhoto):
-                     DBG1("DJ6xxPhoto\n");
-                     p=new DJ6xxPhoto(pSS);
-                     break;
-#endif
-
-#ifdef APDK_DJ630
-            case(eDJ630):
-                     DBG1("DJ630\n");
-                     p=new DJ630(pSS);
-                     break;
-#endif
-
-#ifdef APDK_DJ8xx
-        case(eDJ8xx):
-                     DBG1("DJ8xx\n");
-                     p=new DJ8xx(pSS);
-                     break;
-#endif
-
-#ifdef APDK_DJ8x5
-        case(eDJ8x5):
-                     DBG1("DJ8x5\n");
-                     p = new DJ8x5 (pSS);
-                     break;
-#endif
-
-#ifdef APDK_DJ850
-        case(eDJ850):
-                     DBG1("DJ850\n");
-                     p=new DJ850(pSS);
-                     break;
-#endif
-
-#ifdef APDK_DJ890
-        case(eDJ890):
-                     DBG1("DJ890\n");
-                     p=new DJ890(pSS);
-                     break;
-#endif
- 
-#ifdef APDK_DJ9xx
-            case(eDJ9xx):
-                     DBG1("DJ9xx\n");
-                     p=new DJ9xx(pSS);
-                     break;
-#endif
-
-#ifdef APDK_DJ9xxVIP
-            case(eDJ9xxVIP):
-                     DBG1("DJ9xxVIP\n");
-                     p=new DJ9xxVIP(pSS);
-                     break;
-#endif
-
-#ifdef APDK_DJGENERICVIP
-            case (eDJGenericVIP):
-                     DBG1("DJGenericVIP\n");
-                     p = new DJGenericVIP (pSS);
-                     break;
-#endif
-
-#ifdef APDK_PSP100
-            case (ePSP100):
-                DBG1("PSP100\n");
-                p = new PSP100 (pSS);
-                break;
-#endif
-
-#ifdef APDK_DJ3320
-            case (eDJ3320):
-                DBG1("DJ3320\n");
-                p = new DJ3320 (pSS);
-                break;
-#endif
-
-#ifdef APDK_APOLLO2XXX
-            case(eAP2xxx):
-                     DBG1("Apollo2xxx\n");
-                     p=new Apollo2xxx(pSS);
-                     break;
-#endif
-#ifdef APDK_APOLLO21XX
-            case(eAP21xx):
-                     DBG1("Apollo21xx\n");
-                     p=new Apollo21xx(pSS);
-                     break;
-#endif
-#ifdef APDK_APOLLO2560
-            case(eAP2560):
-                     DBG1("Apollo2560\n");
-                     p=new Apollo2560(pSS);
-                     break;
-#endif
-#ifdef APDK_LJMONO
-			case (eLJMono):
-					DBG1("LJMono\n");
-					p = new LJMono (pSS);
-					break;
-#endif
-#ifdef APDK_LJCOLOR
-			case (eLJColor):
-					DBG1("LJColor\n");
-					p = new LJColor (pSS);
-					break;
-#endif
-#ifdef APDK_PSCRIPT
-			case (ePScript):
-					DBG1("ePScript\n");
-					p = new PScript (pSS);
-					break;
-#endif
-        default:
-                     DBG1("UNSUPPORTED_PRINTER\n");
-                     return UNSUPPORTED_PRINTER;
-                     break;
+    FAMILY_HANDLE familyHandle = pPFI->FindDevIdMatch(ModelName[device]);
+    if (familyHandle == NULL)
+    {
+        ASSERT(familyHandle);
+        DBG1("DR::InstantiatePrinter - no family match\n");
+        return UNSUPPORTED_PRINTER;
     }
-
+    p = pPFI->CreatePrinter(pSS, familyHandle);
     NEWCHECK(p);
-
     return p->constructor_error;
 } //InstantiatePrinter
 
@@ -605,7 +385,10 @@ DRIVER_ERROR DeviceRegistry::ParseDevIDString(const char* sDevID, char* strModel
     // my own version of strtok to pull out the model string here
     i = 0;
     while ( (pStr[i] != ';') && (pStr[i] != '\0') && (i < DevIDBuffSize))
-        strModel[i] = pStr[i++];
+	{
+        strModel[i] = pStr[i];
+		i++;
+	}
     strModel[i] = '\0';
 
 
@@ -671,7 +454,10 @@ DRIVER_ERROR DeviceRegistry::ParseDevIDString(const char* sDevID, char* strModel
         pStr+=8;
         i=0;
         while ( (pStr[i] != ',') && (pStr[i] != ';') && (pStr[i] != '\0') )
-            strPens[i] = pStr[i++];
+		{
+            strPens[i] = pStr[i];
+			i++;
+		}
         strPens[i] = '\0';
     }
     else if ( (pStr = (char *)strstr(sDevID + 2, ";S:00")) ||   // binary encoded device ID status (version 0)
